@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "qdeclarativeviewinspector.h"
 #include "qdeclarativeviewinspector_p.h"
@@ -41,15 +38,15 @@
 
 #include "qt_private/qdeclarativedebughelper_p.h"
 
-#include <QtDeclarative/QDeclarativeItem>
-#include <QtDeclarative/QDeclarativeEngine>
-#include <QtDeclarative/QDeclarativeContext>
-#include <QtDeclarative/QDeclarativeExpression>
-#include <QtGui/QWidget>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QGraphicsObject>
-#include <QtGui/QApplication>
+#include <QDeclarativeItem>
+#include <QDeclarativeEngine>
+#include <QDeclarativeContext>
+#include <QDeclarativeExpression>
+#include <QWidget>
+#include <QVBoxLayout>
+#include <QMouseEvent>
+#include <QGraphicsObject>
+#include <QApplication>
 
 #include "qt_private/qdeclarativestate_p.h"
 
@@ -107,10 +104,10 @@ QDeclarativeViewInspector::QDeclarativeViewInspector(QDeclarativeView *view, QOb
             SIGNAL(objectCreationRequested(QString,QObject*,QStringList,QString,int)),
             data.data(), SLOT(_q_createQmlObject(QString,QObject*,QStringList,QString,int)));
     connect(data->debugService,
-            SIGNAL(objectDeletionRequested(QObject *)), data.data(), SLOT(_q_deleteQmlObject(QObject *)));
+            SIGNAL(objectDeletionRequested(QObject*)), data.data(), SLOT(_q_deleteQmlObject(QObject*)));
     connect(data->debugService,
-            SIGNAL(objectReparentRequested(QObject *, QObject *)),
-            data.data(), SLOT(_q_reparentQmlObject(QObject *, QObject *)));
+            SIGNAL(objectReparentRequested(QObject*,QObject*)),
+            data.data(), SLOT(_q_reparentQmlObject(QObject*,QObject*)));
     connect(data->debugService, SIGNAL(clearComponentCacheRequested()),
             data.data(), SLOT(_q_clearComponentCache()));
     connect(data->view, SIGNAL(statusChanged(QDeclarativeView::Status)),
