@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "qtsingleapplication.h"
 
@@ -54,13 +51,14 @@
 
 #include <QApplication>
 #include <QDesktopServices>
-#include <QMainWindow>
 #include <QMessageBox>
 
 #ifdef ENABLE_QT_BREAKPAD
 #include <qtsystemexceptionhandler.h>
 #endif
 
+using namespace ExtensionSystem;
+
 enum { OptionIndent = 4, DescriptionIndent = 34 };
 
 static const char appNameC[] = "Qt Creator";
@@ -89,7 +87,7 @@ static const char SETTINGS_OPTION[] = "-settingspath";
 static const char PID_OPTION[] = "-pid";
 #endif
 
-typedef QList<ExtensionSystem::PluginSpec *> PluginSpecSet;
+typedef QList<PluginSpec *> PluginSpecSet;
 
 // Helpers for displaying messages. Note that there is no console on Windows.
 #ifdef Q_OS_WIN
@@ -128,24 +126,23 @@ static void displayError(const QString &t)
 
 #endif
 
-static void printVersion(const ExtensionSystem::PluginSpec *coreplugin,
-                         const ExtensionSystem::PluginManager &pm)
+static void printVersion(const PluginSpec *coreplugin)
 {
     QString version;
     QTextStream str(&version);
     str << '\n' << appNameC << ' ' << coreplugin->version()<< " based on Qt " << qVersion() << "\n\n";
-    pm.formatPluginVersions(str);
+    PluginManager::formatPluginVersions(str);
     str << '\n' << coreplugin->copyright() << '\n';
     displayHelpText(version);
 }
 
-static void printHelp(const QString &a0, const ExtensionSystem::PluginManager &pm)
+static void printHelp(const QString &a0)
 {
     QString help;
     QTextStream str(&help);
     str << "Usage: " << a0 << fixedOptionsC;
-    ExtensionSystem::PluginManager::formatOptions(str, OptionIndent, DescriptionIndent);
-    pm.formatPluginOptions(str, OptionIndent, DescriptionIndent);
+    PluginManager::formatOptions(str, OptionIndent, DescriptionIndent);
+    PluginManager::formatPluginOptions(str, OptionIndent, DescriptionIndent);
     displayHelpText(help);
 }
 
@@ -163,6 +160,33 @@ static inline int askMsgSendFailed()
                                  QMessageBox::Retry);
 }
 
+// taken from utils/fileutils.cpp. We can not use utils here since that depends app_version.h.
+static bool copyRecursively(const QString &srcFilePath,
+                            const QString &tgtFilePath)
+{
+    QFileInfo srcFileInfo(srcFilePath);
+    if (srcFileInfo.isDir()) {
+        QDir targetDir(tgtFilePath);
+        targetDir.cdUp();
+        if (!targetDir.mkdir(QFileInfo(tgtFilePath).fileName()))
+            return false;
+        QDir sourceDir(srcFilePath);
+        QStringList fileNames = sourceDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::Hidden | QDir::System);
+        foreach (const QString &fileName, fileNames) {
+            const QString newSrcFilePath
+                    = srcFilePath + QLatin1Char('/') + fileName;
+            const QString newTgtFilePath
+                    = tgtFilePath + QLatin1Char('/') + fileName;
+            if (!copyRecursively(newSrcFilePath, newTgtFilePath))
+                return false;
+        }
+    } else {
+        if (!QFile::copy(srcFilePath, tgtFilePath))
+            return false;
+    }
+    return true;
+}
+
 static inline QStringList getPluginPaths()
 {
     QStringList rc;
@@ -185,9 +209,9 @@ static inline QStringList getPluginPaths()
 #endif
     // 3) <localappdata>/plugins/<ideversion>
     //    where <localappdata> is e.g.
-    //    <drive>:\Users\<username>\AppData\Local\Nokia\qtcreator on Windows Vista and later
-    //    $XDG_DATA_HOME or ~/.local/share/data/Nokia/qtcreator on Linux
-    //    ~/Library/Application Support/Nokia/Qt Creator on Mac
+    //    <drive>:\Users\<username>\AppData\Local\QtProject\qtcreator on Windows Vista and later
+    //    $XDG_DATA_HOME or ~/.local/share/data/QtProject/qtcreator on Linux
+    //    ~/Library/Application Support/QtProject/Qt Creator on Mac
     pluginPath = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
     pluginPath += QLatin1Char('/')
             + QLatin1String(Core::Constants::IDE_SETTINGSVARIANT_STR)
@@ -203,6 +227,55 @@ static inline QStringList getPluginPaths()
     return rc;
 }
 
+static QSettings *createUserSettings()
+{
+    return new QSettings(QSettings::IniFormat, QSettings::UserScope,
+                         QLatin1String(Core::Constants::IDE_SETTINGSVARIANT_STR),
+                         QLatin1String("QtCreator"));
+}
+
+static inline QSettings *userSettings()
+{
+    QSettings *settings = createUserSettings();
+    const QString fromVariant = QLatin1String(Core::Constants::IDE_COPY_SETTINGS_FROM_VARIANT_STR);
+    if (fromVariant.isEmpty())
+        return settings;
+
+    // Copy old settings to new ones:
+    QFileInfo pathFi = QFileInfo(settings->fileName());
+    if (pathFi.exists()) // already copied.
+        return settings;
+
+    QDir destDir = pathFi.absolutePath();
+    if (!destDir.exists())
+        destDir.mkpath(pathFi.absolutePath());
+
+    QDir srcDir = destDir;
+    srcDir.cdUp();
+    if (!srcDir.cd(fromVariant))
+        return settings;
+
+    if (srcDir == destDir) // Nothing to copy and no settings yet
+        return settings;
+
+    QStringList entries = srcDir.entryList();
+    foreach (const QString &file, entries) {
+        const QString lowerFile = file.toLower();
+        if (lowerFile.startsWith(QLatin1String("profiles.xml"))
+                || lowerFile.startsWith(QLatin1String("toolchains.xml"))
+                || lowerFile.startsWith(QLatin1String("qtversion.xml"))
+                || lowerFile.startsWith(QLatin1String("devices.xml"))
+                || lowerFile.startsWith(QLatin1String("qtcreator.")))
+            QFile::copy(srcDir.absoluteFilePath(file), destDir.absoluteFilePath(file));
+        if (file == QLatin1String("qtcreator"))
+            copyRecursively(srcDir.absoluteFilePath(file), destDir.absoluteFilePath(file));
+    }
+
+    // Make sure to use the copied settings:
+    delete settings;
+    return createUserSettings();
+}
+
 #ifdef Q_OS_MAC
 #  define SHARE_PATH "/../Resources"
 #else
@@ -220,7 +293,7 @@ int main(int argc, char **argv)
     setrlimit(RLIMIT_NOFILE, &rl);
 #endif
 
-#ifdef Q_WS_X11
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
     // QML is unusable with the xlib backend
     QApplication::setGraphicsSystem("raster");
 #endif
@@ -258,16 +331,15 @@ int main(int argc, char **argv)
                        QCoreApplication::applicationDirPath() + QLatin1String(SHARE_PATH));
     QSettings::setDefaultFormat(QSettings::IniFormat);
     // plugin manager takes control of this settings object
-    QSettings *settings = new QSettings(QSettings::IniFormat, QSettings::UserScope,
-                                        QLatin1String(Core::Constants::IDE_SETTINGSVARIANT_STR),
-                                        QLatin1String("QtCreator"));
+    QSettings *settings = userSettings();
+
     QSettings *globalSettings = new QSettings(QSettings::IniFormat, QSettings::SystemScope,
                                               QLatin1String(Core::Constants::IDE_SETTINGSVARIANT_STR),
                                               QLatin1String("QtCreator"));
-    ExtensionSystem::PluginManager pluginManager;
-    pluginManager.setFileExtension(QLatin1String("pluginspec"));
-    pluginManager.setGlobalSettings(globalSettings);
-    pluginManager.setSettings(settings);
+    PluginManager pluginManager;
+    PluginManager::setFileExtension(QLatin1String("pluginspec"));
+    PluginManager::setGlobalSettings(globalSettings);
+    PluginManager::setSettings(settings);
 
     QTranslator translator;
     QTranslator qtTranslator;
@@ -283,7 +355,8 @@ int main(int argc, char **argv)
         uiLanguages.prepend(overrideLanguage);
     const QString &creatorTrPath = QCoreApplication::applicationDirPath()
             + QLatin1String(SHARE_PATH "/translations");
-    foreach (const QString &locale, uiLanguages) {
+    foreach (QString locale, uiLanguages) {
+        locale.replace(QLatin1Char('-'), QLatin1Char('_')); // work around QTBUG-25973
         if (translator.load(QLatin1String("qtcreator_") + locale, creatorTrPath)) {
             const QString &qtTrPath = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
             const QString &qtTrFile = QLatin1String("qt_") + locale;
@@ -322,7 +395,7 @@ int main(int argc, char **argv)
 #endif
     // Load
     const QStringList pluginPaths = getPluginPaths();
-    pluginManager.setPluginPaths(pluginPaths);
+    PluginManager::setPluginPaths(pluginPaths);
 
     QMap<QString, QString> foundAppOptions;
     if (arguments.size() > 1) {
@@ -337,16 +410,16 @@ int main(int argc, char **argv)
         appOptions.insert(QLatin1String(PID_OPTION), true);
 #endif
         QString errorMessage;
-        if (!pluginManager.parseOptions(arguments, appOptions, &foundAppOptions, &errorMessage)) {
+        if (!PluginManager::parseOptions(arguments, appOptions, &foundAppOptions, &errorMessage)) {
             displayError(errorMessage);
-            printHelp(QFileInfo(app.applicationFilePath()).baseName(), pluginManager);
+            printHelp(QFileInfo(app.applicationFilePath()).baseName());
             return -1;
         }
     }
 
-    const PluginSpecSet plugins = pluginManager.plugins();
-    ExtensionSystem::PluginSpec *coreplugin = 0;
-    foreach (ExtensionSystem::PluginSpec *spec, plugins) {
+    const PluginSpecSet plugins = PluginManager::plugins();
+    PluginSpec *coreplugin = 0;
+    foreach (PluginSpec *spec, plugins) {
         if (spec->name() == QLatin1String(corePluginNameC)) {
             coreplugin = spec;
             break;
@@ -363,14 +436,14 @@ int main(int argc, char **argv)
         return 1;
     }
     if (foundAppOptions.contains(QLatin1String(VERSION_OPTION))) {
-        printVersion(coreplugin, pluginManager);
+        printVersion(coreplugin);
         return 0;
     }
     if (foundAppOptions.contains(QLatin1String(HELP_OPTION1))
             || foundAppOptions.contains(QLatin1String(HELP_OPTION2))
             || foundAppOptions.contains(QLatin1String(HELP_OPTION3))
             || foundAppOptions.contains(QLatin1String(HELP_OPTION4))) {
-        printHelp(QFileInfo(app.applicationFilePath()).baseName(), pluginManager);
+        printHelp(QFileInfo(app.applicationFilePath()).baseName());
         return 0;
     }
 
@@ -386,7 +459,7 @@ int main(int argc, char **argv)
 #endif
 
     if (app.isRunning() && (pid != -1 || foundAppOptions.contains(QLatin1String(CLIENT_OPTION)))) {
-        if (app.sendMessage(pluginManager.serializedArguments(), 5000 /*timeout*/, pid))
+        if (app.sendMessage(PluginManager::serializedArguments(), 5000 /*timeout*/, pid))
             return 0;
 
         // Message could not be send, maybe it was in the process of quitting
@@ -394,7 +467,7 @@ int main(int argc, char **argv)
             // Nah app is still running, ask the user
             int button = askMsgSendFailed();
             while(button == QMessageBox::Retry) {
-                if (app.sendMessage(pluginManager.serializedArguments(), 5000 /*timeout*/, pid))
+                if (app.sendMessage(PluginManager::serializedArguments(), 5000 /*timeout*/, pid))
                     return 0;
                 if (!app.isRunning(pid)) // App quit while we were trying so start a new creator
                     button = QMessageBox::Yes;
@@ -406,13 +479,13 @@ int main(int argc, char **argv)
         }
     }
 
-    pluginManager.loadPlugins();
+    PluginManager::loadPlugins();
     if (coreplugin->hasError()) {
         displayError(msgCoreLoadFailure(coreplugin->errorString()));
         return 1;
     }
-    if (pluginManager.hasError()) {
-        ExtensionSystem::PluginErrorOverview errorOverview(&pluginManager);
+    if (PluginManager::hasError()) {
+        PluginErrorOverview errorOverview;
         errorOverview.exec();
     }
 
@@ -429,7 +502,7 @@ int main(int argc, char **argv)
 
 #ifdef WITH_TESTS
     // Do this after the event loop has started
-    if (pluginManager.runningTests())
+    if (PluginManager::runningTests())
         QTimer::singleShot(100, &pluginManager, SLOT(startTests()));
 #endif
 
