@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "ResolveExpression.h"
 #include "LookupContext.h"
@@ -49,8 +46,9 @@
 #include <Templates.h>
 
 #include <QList>
-#include <QtDebug>
+#include <QDebug>
 #include <QSet>
+#include <map>
 
 using namespace CPlusPlus;
 
@@ -289,13 +287,16 @@ bool ResolveExpression::visit(NumericLiteralAST *ast)
     Type *type = 0;
     bool isUnsigned = false;
 
-    if (tk.is(T_CHAR_LITERAL))
+    if (tk.is(T_CHAR_LITERAL)) {
         type = control()->integerType(IntegerType::Char);
-    else if (tk.is(T_WIDE_CHAR_LITERAL))
+    } else if (tk.is(T_WIDE_CHAR_LITERAL)) {
         type = control()->integerType(IntegerType::WideChar);
-    else if (const NumericLiteral *literal = numericLiteral(ast->literal_token)) {
+    } else if (tk.is(T_UTF16_CHAR_LITERAL)) {
+        type = control()->integerType(IntegerType::Char16);
+    } else if (tk.is(T_UTF32_CHAR_LITERAL)) {
+        type = control()->integerType(IntegerType::Char32);
+    } else if (const NumericLiteral *literal = numericLiteral(ast->literal_token)) {
         isUnsigned = literal->isUnsigned();
-
         if (literal->isInt())
             type = control()->integerType(IntegerType::Int);
         else if (literal->isLong())
@@ -459,6 +460,48 @@ bool ResolveExpression::visit(QualifiedNameAST *ast)
     return false;
 }
 
+namespace {
+
+class DeduceAutoCheck : public ASTVisitor
+{
+public:
+    DeduceAutoCheck(const Identifier *id, TranslationUnit *tu)
+        : ASTVisitor(tu), _id(id), _block(false)
+    {
+        accept(tu->ast());
+    }
+
+    virtual bool preVisit(AST *)
+    {
+        if (_block)
+            return false;
+
+        return true;
+    }
+
+    virtual bool visit(SimpleNameAST *ast)
+    {
+        if (ast->name
+                && ast->name->identifier()
+                && strcmp(ast->name->identifier()->chars(), _id->chars()) == 0) {
+            _block = true;
+        }
+
+        return false;
+    }
+
+    virtual bool visit(MemberAccessAST *ast)
+    {
+        accept(ast->base_expression);
+        return false;
+    }
+
+    const Identifier *_id;
+    bool _block;
+};
+
+} // namespace anonymous
+
 bool ResolveExpression::visit(SimpleNameAST *ast)
 {
     QList<LookupItem> candidates = _context.lookup(ast->name, _scope);
@@ -477,22 +520,32 @@ bool ResolveExpression::visit(SimpleNameAST *ast)
             if (!decl)
                 continue;
 
-            Document::Ptr doc = _context.snapshot().document(decl->fileName());
-
             const StringLiteral *initializationString = decl->getInitializer();
             if (initializationString == 0)
                 continue;
 
-            QByteArray initializer = QByteArray::fromRawData(initializationString->chars(), initializationString->size()).trimmed();
+            const QByteArray &initializer =
+                    QByteArray::fromRawData(initializationString->chars(),
+                                            initializationString->size()).trimmed();
 
             // Skip lambda-function initializers
             if (initializer.length() > 0 && initializer[0] == '[')
                 continue;
 
             TypeOfExpression exprTyper;
+            Document::Ptr doc = _context.snapshot().document(decl->fileName());
             exprTyper.init(doc, _context.snapshot(), _context.bindings());
 
-            QList<LookupItem> typeItems = exprTyper(initializer, decl->enclosingScope(), TypeOfExpression::Preprocess);
+            Document::Ptr exprDoc =
+                    documentForExpression(exprTyper.preprocessedExpression(initializer));
+            exprDoc->check();
+
+            DeduceAutoCheck deduceAuto(ast->name->identifier(), exprDoc->translationUnit());
+            if (deduceAuto._block)
+                continue;
+
+            const QList<LookupItem> &typeItems =
+                    exprTyper(extractExpressionAST(exprDoc), exprDoc, decl->enclosingScope());
             if (typeItems.empty())
                 continue;
 
@@ -577,7 +630,8 @@ bool ResolveExpression::visit(CallAST *ast)
     }
 
     if (_reference) {
-        _results.clear();
+        typedef std::multimap<int, LookupItem> LookupMap;
+        LookupMap sortedResults;
         foreach (const LookupItem &base, baseResults) {
             if (Function *funTy = base.type()->asFunctionType()) {
                 if (! maybeValidPrototype(funTy, actualArgumentCount))
@@ -602,13 +656,13 @@ bool ResolveExpression::visit(CallAST *ast)
                         ++score;
                 }
 
-                if (score)
-                    _results.prepend(base);
-                else
-                    _results.append(base);
+                sortedResults.insert(LookupMap::value_type(-score, base));
             }
         }
 
+        _results.clear();
+        for (LookupMap::const_iterator it = sortedResults.begin(); it != sortedResults.end(); ++it)
+            _results.append(it->second);
         if (_results.isEmpty())
             _results = baseResults;
 
@@ -776,16 +830,22 @@ ClassOrNamespace *ResolveExpression::findClass(const FullySpecifiedType &origina
 
 static void resolveTypedefs(const LookupContext &context,
                             FullySpecifiedType *type,
-                            Scope **scope)
+                            Scope **scope, ClassOrNamespace *binding)
 {
     QSet<Symbol *> visited;
     while (NamedType *namedTy = (*type)->asNamedType()) {
-        ClassOrNamespace *scopeCoN = context.lookupType(*scope);
-        if (!scopeCoN)
-            break;
 
         // check if namedTy->name() resolves to a typedef
-        QList<LookupItem> namedTypeItems = scopeCoN->lookup(namedTy->name());
+        QList<LookupItem> namedTypeItems;
+        if (binding)
+            namedTypeItems = binding->lookup(namedTy->name());
+        if (ClassOrNamespace *scopeCon = context.lookupType(*scope))
+            namedTypeItems += scopeCon->lookup(namedTy->name());
+
+#ifdef DEBUG_LOOKUP
+        qDebug() << "-- we have" << namedTypeItems.size() << "candidates";
+#endif // DEBUG_LOOKUP
+
         bool foundTypedef = false;
         foreach (const LookupItem &it, namedTypeItems) {
             if (it.declaration() && it.declaration()->isTypedef()) {
@@ -810,11 +870,26 @@ ClassOrNamespace *ResolveExpression::baseExpression(const QList<LookupItem> &bas
                                                     int accessOp,
                                                     bool *replacedDotOperator) const
 {
+#ifdef DEBUG_LOOKUP
+    qDebug() << "In ResolveExpression::baseExpression with" << baseResults.size() << "results...";
+    int i = 0;
+    Overview oo;
+#endif // DEBUG_LOOKUP
+
     foreach (const LookupItem &r, baseResults) {
         FullySpecifiedType ty = r.type().simplified();
         Scope *scope = r.scope();
 
-        resolveTypedefs(_context, &ty, &scope);
+#ifdef DEBUG_LOOKUP
+        qDebug("trying result #%d", ++i);
+        qDebug()<<"- before typedef resolving we have:"<<oo(ty);
+#endif // DEBUG_LOOKUP
+
+        resolveTypedefs(_context, &ty, &scope, r.binding());
+
+#ifdef DEBUG_LOOKUP
+        qDebug()<<"-  after typedef resolving:"<<oo(ty);
+#endif // DEBUG_LOOKUP
 
         if (accessOp == T_ARROW) {
             if (PointerType *ptrTy = ty->asPointerType()) {
@@ -838,7 +913,7 @@ ClassOrNamespace *ResolveExpression::baseExpression(const QList<LookupItem> &bas
 
                         FullySpecifiedType retTy = instantiatedFunction->returnType().simplified();
 
-                        resolveTypedefs(_context, &retTy, &functionScope);
+                        resolveTypedefs(_context, &retTy, &functionScope, r.binding());
 
                         if (PointerType *ptrTy = retTy->asPointerType()) {
                             if (ClassOrNamespace *retBinding = findClass(ptrTy->elementType(), functionScope))
