@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "buildablehelperlibrary.h"
 
@@ -110,7 +107,9 @@ QString BuildableHelperLibrary::qtVersionForQMake(const QString &qmakePath, bool
     static QRegExp regexp(QLatin1String("(QMake version|QMake version:)[\\s]*([\\d.]*)"),
                           Qt::CaseInsensitive);
     regexp.indexIn(output);
-    if (regexp.cap(2).startsWith(QLatin1String("2."))) {
+    const QString qmakeVersion = regexp.cap(2);
+    if (qmakeVersion.startsWith(QLatin1String("2."))
+            || qmakeVersion.startsWith(QLatin1String("3."))) {
         static QRegExp regexp2(QLatin1String("Using Qt version[\\s]*([\\d\\.]*)"),
                                Qt::CaseInsensitive);
         regexp2.indexIn(output);
@@ -128,7 +127,8 @@ QStringList BuildableHelperLibrary::possibleQMakeCommands()
 #else
     // On unix some distributions renamed qmake to avoid clashes
     QStringList result;
-    result << QLatin1String("qmake-qt4") << QLatin1String("qmake4") << QLatin1String("qmake");
+    result << QLatin1String("qmake-qt4") << QLatin1String("qmake4")
+           << QLatin1String("qmake-qt5") << QLatin1String("qmake5") << QLatin1String("qmake");
     return result;
 #endif
 }
