@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "bineditorplugin.h"
 #include "bineditor.h"
@@ -46,7 +43,6 @@
 
 #include <QMenu>
 #include <QAction>
-#include <QMainWindow>
 #include <QMessageBox>
 #include <QHBoxLayout>
 #include <QLineEdit>
@@ -171,13 +167,6 @@ public:
         return result;
     }
 
-    void replace(const QString &, const QString &,
-                 Find::FindFlags) { }
-    bool replaceStep(const QString &, const QString &,
-                     Find::FindFlags) { return false;}
-    int replaceAll(const QString &, const QString &,
-                   Find::FindFlags) { return 0; }
-
 private:
     BinEditor *m_editor;
     int m_incrementalStartPos;
@@ -232,7 +221,16 @@ public:
 
     bool open(QString *errorString, const QString &fileName, quint64 offset = 0) {
         QFile file(fileName);
-        if (offset >= static_cast<quint64>(file.size()))
+        quint64 size = static_cast<quint64>(file.size());
+        if (size == 0) {
+            QString msg = tr("The Binary Editor cannot open empty files.");
+            if (errorString)
+                *errorString = msg;
+            else
+                QMessageBox::critical(Core::ICore::mainWindow(), tr("File Error"), msg);
+            return false;
+        }
+        if (offset >= size)
             return false;
         if (file.open(QIODevice::ReadOnly)) {
             file.close();
@@ -382,8 +380,8 @@ public:
     bool duplicateSupported() const { return false; }
     IEditor *duplicate(QWidget * /* parent */) { return 0; }
 
-    QByteArray saveState() const { return QByteArray(); } // TODO
-    bool restoreState(const QByteArray & /* state */) { return false; } // TODO
+    QByteArray saveState() const { return QByteArray(); } // not supported
+    bool restoreState(const QByteArray & /* state */) { return false; }  // not supported
 
     QWidget *toolBar() { return m_toolBar; }
 
@@ -427,13 +425,6 @@ QString BinEditorFactory::displayName() const
     return qApp->translate("OpenWith::Editors", Constants::C_BINEDITOR_DISPLAY_NAME);
 }
 
-Core::IDocument *BinEditorFactory::open(const QString &fileName)
-{
-    Core::EditorManager *em = Core::EditorManager::instance();
-    Core::IEditor *iface = em->openEditor(fileName, id());
-    return iface ? iface->document() : 0;
-}
-
 Core::IEditor *BinEditorFactory::createEditor(QWidget *parent)
 {
     BinEditor *editor = new BinEditor(parent);
@@ -475,14 +466,14 @@ BinEditorPlugin::~BinEditorPlugin()
 {
 }
 
-QAction *BinEditorPlugin::registerNewAction(const QString &id, const QString &title)
+QAction *BinEditorPlugin::registerNewAction(Core::Id id, const QString &title)
 {
     QAction *result = new QAction(title, this);
-    Core::ICore::actionManager()->registerAction(result, Core::Id(id), m_context);
+    Core::ActionManager::registerAction(result, id, m_context);
     return result;
 }
 
-QAction *BinEditorPlugin::registerNewAction(const QString &id,
+QAction *BinEditorPlugin::registerNewAction(Core::Id id,
                                             QObject *receiver,
                                             const char *slot,
                                             const QString &title)
@@ -503,16 +494,10 @@ void BinEditorPlugin::initializeEditor(BinEditor *editor)
 
     m_context.add(Constants::C_BINEDITOR);
     if (!m_undoAction) {
-        m_undoAction      = registerNewAction(QLatin1String(Core::Constants::UNDO),
-                                              this, SLOT(undoAction()),
-                                              tr("&Undo"));
-        m_redoAction      = registerNewAction(QLatin1String(Core::Constants::REDO),
-                                              this, SLOT(redoAction()),
-                                              tr("&Redo"));
-        m_copyAction      = registerNewAction(QLatin1String(Core::Constants::COPY),
-                                              this, SLOT(copyAction()));
-        m_selectAllAction = registerNewAction(QLatin1String(Core::Constants::SELECTALL),
-                                              this, SLOT(selectAllAction()));
+        m_undoAction      = registerNewAction(Core::Constants::UNDO, this, SLOT(undoAction()), tr("&Undo"));
+        m_redoAction      = registerNewAction(Core::Constants::REDO, this, SLOT(redoAction()), tr("&Redo"));
+        m_copyAction      = registerNewAction(Core::Constants::COPY, this, SLOT(copyAction()));
+        m_selectAllAction = registerNewAction(Core::Constants::SELECTALL, this, SLOT(selectAllAction()));
     }
 
     // Font settings
