@@ -1,55 +1,50 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "commandmappings.h"
+#include "shortcutsettings.h"
 #include "ui_commandmappings.h"
-#include "actionmanager_p.h"
-#include "actionmanager/command.h"
-#include "command_p.h"
 #include "commandsfile.h"
 #include "coreconstants.h"
-#include "filemanager.h"
+#include "documentmanager.h"
 #include "icore.h"
 #include "id.h"
 
 #include <utils/treewidgetcolumnstretcher.h>
 
-#include <QtGui/QKeyEvent>
-#include <QtGui/QShortcut>
-#include <QtGui/QHeaderView>
-#include <QtGui/QTreeWidgetItem>
-#include <QtGui/QFileDialog>
-#include <QtCore/QCoreApplication>
-#include <QtDebug>
+#include <QKeyEvent>
+#include <QShortcut>
+#include <QHeaderView>
+#include <QTreeWidgetItem>
+#include <QFileDialog>
+#include <QCoreApplication>
+#include <QDebug>
 
 Q_DECLARE_METATYPE(Core::Internal::ShortcutItem*)
 
@@ -61,15 +56,11 @@ CommandMappings::CommandMappings(QObject *parent)
 {
 }
 
-CommandMappings::~CommandMappings()
-{
-}
-
 // IOptionsPage
 
 QWidget *CommandMappings::createPage(QWidget *parent)
 {
-    m_page = new Ui_CommandMappings();
+    m_page = new Ui::CommandMappings();
     QWidget *w = new QWidget(parent);
     m_page->setupUi(w);
     m_page->targetEdit->setAutoHideButton(Utils::FancyLineEdit::Right, true);
@@ -92,8 +83,8 @@ QWidget *CommandMappings::createPage(QWidget *parent)
 
     connect(m_page->filterEdit, SIGNAL(textChanged(QString)),
         this, SLOT(filterChanged(QString)));
-    connect(m_page->commandList, SIGNAL(currentItemChanged(QTreeWidgetItem *, QTreeWidgetItem *)),
-        this, SLOT(commandChanged(QTreeWidgetItem *)));
+    connect(m_page->commandList, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
+        this, SLOT(commandChanged(QTreeWidgetItem*)));
     connect(m_page->targetEdit, SIGNAL(textChanged(QString)),
         this, SLOT(targetIdentifierChanged()));
 
@@ -151,7 +142,7 @@ void CommandMappings::finish()
 void CommandMappings::commandChanged(QTreeWidgetItem *current)
 {
     if (!current || !current->data(0, Qt::UserRole).isValid()) {
-        m_page->targetEdit->setText("");
+        m_page->targetEdit->setText(QString());
         m_page->targetEditGroup->setEnabled(false);
         return;
     }
@@ -164,38 +155,42 @@ void CommandMappings::filterChanged(const QString &f)
         return;
     for (int i=0; i<m_page->commandList->topLevelItemCount(); ++i) {
         QTreeWidgetItem *item = m_page->commandList->topLevelItem(i);
-        item->setHidden(filter(f, item));
+        filter(f, item);
     }
 }
 
-bool CommandMappings::filter(const QString &f, const QTreeWidgetItem *item)
+bool CommandMappings::filter(const QString &filterString, QTreeWidgetItem *item)
 {
-    if (QTreeWidgetItem *parent = item->parent()) {
-        if (parent->text(0).contains(f, Qt::CaseInsensitive))
-            return false;
+    bool visible = filterString.isEmpty();
+    int columnCount = item->columnCount();
+    for (int i = 0; !visible && i < columnCount; ++i) {
+        QString text = item->text(i);
+#ifdef Q_OS_MAC
+        // accept e.g. Cmd+E in the filter. the text shows special fancy characters for Cmd
+        if (i == columnCount - 1) {
+            QKeySequence key = QKeySequence::fromString(text, QKeySequence::NativeText);
+            if (!key.isEmpty()) {
+                text = key.toString(QKeySequence::PortableText);
+                text.replace(QLatin1String("Ctrl"), QLatin1String("Cmd"));
+                text.replace(QLatin1String("Meta"), QLatin1String("Ctrl"));
+                text.replace(QLatin1String("Alt"), QLatin1String("Opt"));
+            }
+        }
+#endif
+        visible |= (bool)text.contains(filterString, Qt::CaseInsensitive);
     }
 
-    if (item->childCount() == 0) {
-        if (f.isEmpty())
-            return false;
-        for (int i = 0; i < item->columnCount(); ++i) {
-            if (item->text(i).contains(f, Qt::CaseInsensitive))
-                return false;
-        }
-        return true;
-    }
-
-    bool found = false;
-    for (int i = 0; i < item->childCount(); ++i) {
-        QTreeWidgetItem *citem = item->child(i);
-        if (filter(f, citem)) {
-            citem->setHidden(true);
-        } else {
-            citem->setHidden(false);
-            found = true;
+    int childCount = item->childCount();
+    if (childCount > 0) {
+        // force visibility if this item matches
+        QString leafFilterString = visible ? QString() : filterString;
+        for (int i = 0; i < childCount; ++i) {
+            QTreeWidgetItem *citem = item->child(i);
+            visible |= !filter(leafFilterString, citem); // parent visible if any child visible
         }
     }
-    return !found;
+    item->setHidden(!visible);
+    return !visible;
 }
 
 void CommandMappings::setModified(QTreeWidgetItem *item , bool modified)
