@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "editorview.h"
 #include "editormanager.h"
@@ -264,7 +261,7 @@ void EditorView::setCurrentEditor(IEditor *editor)
         || m_container->indexOf(editor->widget()) == -1) {
         m_toolBar->updateEditorStatus(0);
         m_infoBarDisplay->setInfoBar(0);
-        // ### TODO the combo box m_editorList should show an empty item
+        QTC_CHECK(m_container->count() == 0);
         return;
     }
 
@@ -416,11 +413,12 @@ void EditorView::goBackInNavigationHistory()
     while (m_currentNavigationHistoryPosition > 0) {
         --m_currentNavigationHistoryPosition;
         EditLocation location = m_navigationHistory.at(m_currentNavigationHistoryPosition);
-        IEditor *editor;
+        IEditor *editor = 0;
         if (location.document) {
             editor = em->activateEditorForDocument(this, location.document,
                                         EditorManager::IgnoreNavigationHistory | EditorManager::ModeSwitch);
-        } else {
+        }
+        if (!editor) {
             editor = em->openEditor(this, location.fileName, location.id,
                                     EditorManager::IgnoreNavigationHistory | EditorManager::ModeSwitch);
             if (!editor) {
@@ -442,11 +440,12 @@ void EditorView::goForwardInNavigationHistory()
         return;
     ++m_currentNavigationHistoryPosition;
     EditLocation location = m_navigationHistory.at(m_currentNavigationHistoryPosition);
-    IEditor *editor;
+    IEditor *editor = 0;
     if (location.document) {
         editor = em->activateEditorForDocument(this, location.document,
                                     EditorManager::IgnoreNavigationHistory | EditorManager::ModeSwitch);
-    } else {
+    }
+    if (!editor) {
         editor = em->openEditor(this, location.fileName, location.id, EditorManager::IgnoreNavigationHistory);
         if (!editor) {
             //TODO
@@ -798,7 +797,6 @@ QByteArray SplitterOrView::saveState() const
                 << static_cast<SplitterOrView*>(m_splitter->widget(1))->saveState();
     } else {
         IEditor* e = editor();
-        EditorManager *em = ICore::editorManager();
 
         // don't save state of temporary or ad-hoc editors
         if (e && (e->isTemporary() || e->document()->fileName().isEmpty())) {
@@ -814,7 +812,7 @@ QByteArray SplitterOrView::saveState() const
 
         if (!e) {
             stream << QByteArray("empty");
-        } else if (e == em->currentEditor()) {
+        } else if (e == EditorManager::currentEditor()) {
             stream << QByteArray("currenteditor")
                     << e->document()->fileName() << e->id().toString() << e->saveState();
         } else {
