@@ -1,46 +1,43 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "pasteview.h"
 #include "protocol.h"
 
 #include <coreplugin/icore.h>
 
-#include <QtGui/QFontMetrics>
-#include <QtGui/QPainter>
-#include <QtGui/QScrollBar>
-#include <QtGui/QPushButton>
-#include <QtCore/QSettings>
-#include <QtCore/QByteArray>
+#include <QFontMetrics>
+#include <QPainter>
+#include <QScrollBar>
+#include <QPushButton>
+#include <QSettings>
+#include <QByteArray>
 
 static const char groupC[] = "CPaster";
 static const char heightKeyC[] = "PasteViewHeight";
@@ -93,12 +90,12 @@ QString PasteView::comment() const
     return comment;
 }
 
-QByteArray PasteView::content() const
+QString PasteView::content() const
 {
     if (m_mode == PlainTextMode)
-        return m_ui.plainTextEdit->toPlainText().toUtf8();
+        return m_ui.plainTextEdit->toPlainText();
 
-    QByteArray newContent;
+    QString newContent;
     for (int i = 0; i < m_ui.uiPatchList->count(); ++i) {
         QListWidgetItem *item = m_ui.uiPatchList->item(i);
         if (item->checkState() != Qt::Unchecked)
@@ -137,7 +134,7 @@ int PasteView::showDialog()
     m_ui.uiDescription->selectAll();
 
     // (Re)store dialog size
-    const QSettings *settings = Core::ICore::instance()->settings();
+    const QSettings *settings = Core::ICore::settings();
     const QString rootKey = QLatin1String(groupC) + QLatin1Char('/');
     const int h = settings->value(rootKey + QLatin1String(heightKeyC), height()).toInt();
     const int defaultWidth = m_ui.uiPatchView->columnIndicator() + 50;
@@ -157,7 +154,7 @@ int PasteView::show(const QString &user, const QString &description,
     m_ui.uiPatchList->clear();
     m_parts = parts;
     m_mode = DiffChunkMode;
-    QByteArray content;
+    QString content;
     foreach (const FileData &part, parts) {
         QListWidgetItem *itm = new QListWidgetItem(part.filename, m_ui.uiPatchList);
         itm->setCheckState(Qt::Checked);
@@ -191,14 +188,14 @@ void PasteView::accept()
     if (!Protocol::ensureConfiguration(protocol, this))
         return;
 
-    const QByteArray data = content();
+    const QString data = content();
     if (data.isEmpty())
         return;
 
     const Protocol::ContentType ct = Protocol::contentType(m_mimeType);
     protocol->paste(data, ct, user(), comment(), description());
     // Store settings and close
-    QSettings *settings = Core::ICore::instance()->settings();
+    QSettings *settings = Core::ICore::settings();
     settings->beginGroup(QLatin1String(groupC));
     settings->setValue(QLatin1String(heightKeyC), height());
     settings->setValue(QLatin1String(widthKeyC), width());
