@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "cppcodestylesettingspage.h"
 #include "cppcodestylepreferences.h"
@@ -45,8 +42,8 @@
 #include <extensionsystem/pluginmanager.h>
 #include <cppeditor/cppeditorconstants.h>
 #include <coreplugin/icore.h>
-#include <QtGui/QTextBlock>
-#include <QtCore/QTextStream>
+#include <QTextBlock>
+#include <QTextStream>
 
 static const char *defaultCodeStyleSnippets[] = {
     "#include <math.h>\n"
@@ -452,7 +449,7 @@ void CppCodeStylePreferencesWidget::decorateEditors(const TextEditor::FontSettin
 {
     const ISnippetProvider *provider = 0;
     const QList<ISnippetProvider *> &providers =
-        ExtensionSystem::PluginManager::instance()->getObjects<ISnippetProvider>();
+        ExtensionSystem::PluginManager::getObjects<ISnippetProvider>();
     foreach (const ISnippetProvider *current, providers) {
         if (current->groupId() == QLatin1String(CppEditor::Constants::CPP_SNIPPETS_GROUP_ID)) {
             provider = current;
@@ -479,40 +476,15 @@ void CppCodeStylePreferencesWidget::setVisualizeWhitespace(bool on)
 
 // ------------------ CppCodeStyleSettingsPage
 
-CppCodeStyleSettingsPage::CppCodeStyleSettingsPage(
-        QWidget *parent) :
+CppCodeStyleSettingsPage::CppCodeStyleSettingsPage(QWidget *parent) :
     Core::IOptionsPage(parent),
     m_pageCppCodeStylePreferences(0)
 {
-}
-
-CppCodeStyleSettingsPage::~CppCodeStyleSettingsPage()
-{
-}
-
-QString CppCodeStyleSettingsPage::id() const
-{
-    return QLatin1String(Constants::CPP_CODE_STYLE_SETTINGS_ID);
-}
-
-QString CppCodeStyleSettingsPage::displayName() const
-{
-    return QCoreApplication::translate("CppTools", Constants::CPP_CODE_STYLE_SETTINGS_NAME);
-}
-
-QString CppCodeStyleSettingsPage::category() const
-{
-    return QLatin1String(Constants::CPP_SETTINGS_CATEGORY);
-}
-
-QString CppCodeStyleSettingsPage::displayCategory() const
-{
-    return QCoreApplication::translate("CppTools", Constants::CPP_SETTINGS_TR_CATEGORY);
-}
-
-QIcon CppCodeStyleSettingsPage::categoryIcon() const
-{
-    return QIcon(QLatin1String(Constants::SETTINGS_CATEGORY_CPP_ICON));
+    setId(QLatin1String(Constants::CPP_CODE_STYLE_SETTINGS_ID));
+    setDisplayName(QCoreApplication::translate("CppTools", Constants::CPP_CODE_STYLE_SETTINGS_NAME));
+    setCategory(QLatin1String(Constants::CPP_SETTINGS_CATEGORY));
+    setDisplayCategory(QCoreApplication::translate("CppTools", Constants::CPP_SETTINGS_TR_CATEGORY));
+    setCategoryIcon(QLatin1String(Constants::SETTINGS_CATEGORY_CPP_ICON));
 }
 
 QWidget *CppCodeStyleSettingsPage::createPage(QWidget *parent)
@@ -535,7 +507,7 @@ QWidget *CppCodeStyleSettingsPage::createPage(QWidget *parent)
 void CppCodeStyleSettingsPage::apply()
 {
     if (m_widget) {
-        QSettings *s = Core::ICore::instance()->settings();
+        QSettings *s = Core::ICore::settings();
 
         CppCodeStylePreferences *originalCppCodeStylePreferences = CppToolsSettings::instance()->cppCodeStyle();
         if (originalCppCodeStylePreferences->codeStyleSettings() != m_pageCppCodeStylePreferences->codeStyleSettings()) {
