@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include <cplusplus/pp.h>
 #include <cplusplus/Overview.h>
@@ -96,7 +93,7 @@
 namespace CPlusPlus {
 uint qHash(const CppModelManagerInterface::ProjectPart &p)
 {
-    uint h = qHash(p.defines) ^ p.language ^ p.flags;
+    uint h = qHash(p.defines) ^ p.language ^ ((int) p.cxx11Enabled);
 
     foreach (const QString &i, p.includePaths)
         h ^= qHash(i);
@@ -113,7 +110,7 @@ bool operator==(const CppModelManagerInterface::ProjectPart &p1,
         return false;
     if (p1.language != p2.language)
         return false;
-    if (p1.flags != p2.flags)
+    if (p1.cxx11Enabled != p2.cxx11Enabled)
         return false;
     if (p1.includePaths != p2.includePaths)
         return false;
@@ -201,9 +198,10 @@ static const char pp_configuration[] =
     "#define __forceinline inline\n";
 
 #ifndef ICHECK_BUILD
-CppPreprocessor::CppPreprocessor(QPointer<CppModelManager> modelManager)
+CppPreprocessor::CppPreprocessor(QPointer<CppModelManager> modelManager, bool dumpFileNameWhileParsing)
     : snapshot(modelManager->snapshot()),
       m_modelManager(modelManager),
+      m_dumpFileNameWhileParsing(dumpFileNameWhileParsing),
       preprocess(this, &env),
       m_revision(0)
 {
@@ -214,6 +212,7 @@ CppPreprocessor::CppPreprocessor(QPointer<CppModelManager> modelManager)
 
 CppPreprocessor::CppPreprocessor(QPointer<CPlusPlus::ParseManager> modelManager)
     : preprocess(this, &env),
+      m_dumpFileNameWhileParsing(false),
       m_revision(0)
 {
 }
@@ -338,7 +337,7 @@ public:
 void CppPreprocessor::run(const QString &fileName)
 {
     QString absoluteFilePath = fileName;
-    sourceNeeded(absoluteFilePath, IncludeGlobal, /*line = */ 0);
+    sourceNeeded(0, absoluteFilePath, IncludeGlobal);
 }
 
 void CppPreprocessor::resetEnvironment()
@@ -367,9 +366,11 @@ bool CppPreprocessor::includeFile(const QString &absoluteFilePath, QString *resu
     QFile file(absoluteFilePath);
     if (file.open(QFile::ReadOnly | QFile::Text)) {
         m_included.insert(absoluteFilePath);
+        QTextCodec *defaultCodec = Core::EditorManager::instance()->defaultTextCodec();
         QTextStream stream(&file);
-        const QString contents = stream.readAll();
-        *result = contents.toUtf8();
+        stream.setCodec(defaultCodec);
+        if (result)
+            *result = stream.readAll();
         file.close();
         return true;
     }
@@ -497,35 +498,47 @@ void CppPreprocessor::macroAdded(const Macro &macro)
     m_currentDoc->appendMacro(macro);
 }
 
-void CppPreprocessor::passedMacroDefinitionCheck(unsigned offset, const Macro &macro)
+static inline const Macro revision(const CppModelManagerInterface::WorkingCopy &s, const Macro &macro)
+{
+    Macro newMacro(macro);
+    newMacro.setFileRevision(s.get(macro.fileName()).second);
+    return newMacro;
+}
+
+void CppPreprocessor::passedMacroDefinitionCheck(unsigned offset, unsigned line, const Macro &macro)
 {
     if (! m_currentDoc)
         return;
 
-    m_currentDoc->addMacroUse(macro, offset, macro.name().length(), env.currentLine,
-                              QVector<MacroArgumentReference>(), true);
+    m_currentDoc->addMacroUse(revision(m_workingCopy, macro), offset, macro.name().length(), line,
+                              QVector<MacroArgumentReference>());
 }
 
-void CppPreprocessor::failedMacroDefinitionCheck(unsigned offset, const QByteArray &name)
+void CppPreprocessor::failedMacroDefinitionCheck(unsigned offset, const ByteArrayRef &name)
 {
     if (! m_currentDoc)
         return;
 
-    m_currentDoc->addUndefinedMacroUse(name, offset);
+    m_currentDoc->addUndefinedMacroUse(QByteArray(name.start(), name.size()), offset);
 }
 
-void CppPreprocessor::startExpandingMacro(unsigned offset,
+void CppPreprocessor::notifyMacroReference(unsigned offset, unsigned line, const Macro &macro)
+{
+    if (! m_currentDoc)
+        return;
+
+    m_currentDoc->addMacroUse(revision(m_workingCopy, macro), offset, macro.name().length(), line,
+                              QVector<MacroArgumentReference>());
+}
+
+void CppPreprocessor::startExpandingMacro(unsigned offset, unsigned line,
                                           const Macro &macro,
-                                          const QByteArray &originalText,
-                                          bool inCondition,
                                           const QVector<MacroArgumentReference> &actuals)
 {
     if (! m_currentDoc)
         return;
 
-    //qDebug() << "start expanding:" << macro.name() << "text:" << originalText;
-    m_currentDoc->addMacroUse(macro, offset, originalText.length(), env.currentLine,
-                              actuals, inCondition);
+    m_currentDoc->addMacroUse(revision(m_workingCopy, macro), offset, macro.name().length(), line, actuals);
 }
 
 void CppPreprocessor::stopExpandingMacro(unsigned, const Macro &)
@@ -574,7 +587,7 @@ void CppPreprocessor::stopSkippingBlocks(unsigned offset)
         m_currentDoc->stopSkippingBlocks(offset);
 }
 
-void CppPreprocessor::sourceNeeded(QString &fileName, IncludeType type, unsigned line)
+void CppPreprocessor::sourceNeeded(unsigned line, QString &fileName, IncludeType type)
 {
     if (fileName.isEmpty())
         return;
@@ -591,7 +604,7 @@ void CppPreprocessor::sourceNeeded(QString &fileName, IncludeType type, unsigned
 
             Document::DiagnosticMessage d(Document::DiagnosticMessage::Warning,
                                           m_currentDoc->fileName(),
-                                          env.currentLine, /*column = */ 0,
+                                          line, /*column = */ 0,
                                           msg);
 
             m_currentDoc->addDiagnosticMessage(d);
@@ -600,7 +613,11 @@ void CppPreprocessor::sourceNeeded(QString &fileName, IncludeType type, unsigned
         }
     }
 
-    //qDebug() << "parse file:" << fileName << "contents:" << contents.size();
+    if (m_dumpFileNameWhileParsing) {
+        qDebug() << "Parsing file:" << fileName
+//             << "contents:" << contents.size()
+                    ;
+    }
 
     Document::Ptr doc = snapshot.document(fileName);
     if (doc) {
@@ -618,7 +635,9 @@ void CppPreprocessor::sourceNeeded(QString &fileName, IncludeType type, unsigned
 
     Document::Ptr previousDoc = switchDocument(doc);
 
-    const QByteArray preprocessedCode = preprocess(fileName, contents);
+    const QByteArray preprocessedCode = preprocess.run(fileName, contents);
+
+//    { QByteArray b(preprocessedCode); b.replace("\n", "<<<\n"); qDebug("Preprocessed code for \"%s\": [[%s]]", fileName.toUtf8().constData(), b.constData()); }
 
     doc->setUtf8Source(preprocessedCode);
     doc->keepSourceAndAST();
@@ -673,8 +692,8 @@ void CppModelManager::updateModifiedSourceFiles()
 
 CppModelManager *CppModelManager::instance()
 {
-    ExtensionSystem::PluginManager *pluginManager = ExtensionSystem::PluginManager::instance();
-    return pluginManager->getObject<CppModelManager>();
+    // TODO this is pretty stupid. use regular singleton pattern.
+    return ExtensionSystem::PluginManager::getObject<CppModelManager>();
 }
 
 
@@ -692,6 +711,7 @@ CppModelManager::CppModelManager(QObject *parent)
 {
     m_findReferences = new CppFindReferences(this);
     m_indexerEnabled = qgetenv("QTCREATOR_NO_CODE_INDEXER").isNull();
+    m_dumpFileNameWhileParsing = !qgetenv("QTCREATOR_DUMP_FILENAME_WHILE_PARSING").isNull();
 
     m_revision = 0;
     m_synchronizer.setCancelOnWait(true);
@@ -736,14 +756,14 @@ CppModelManager::CppModelManager(QObject *parent)
 
     m_completionFallback = new InternalCompletionAssistProvider;
     m_completionAssistProvider = m_completionFallback;
-    ExtensionSystem::PluginManager::instance()->addObject(m_completionAssistProvider);
+    ExtensionSystem::PluginManager::addObject(m_completionAssistProvider);
     m_highlightingFallback = new CppHighlightingSupportInternalFactory;
     m_highlightingFactory = m_highlightingFallback;
 }
 
 CppModelManager::~CppModelManager()
 {
-    ExtensionSystem::PluginManager::instance()->removeObject(m_completionAssistProvider);
+    ExtensionSystem::PluginManager::removeObject(m_completionAssistProvider);
     delete m_completionFallback;
     delete m_highlightingFallback;
 }
@@ -864,6 +884,11 @@ void CppModelManager::findMacroUsages(const CPlusPlus::Macro &macro)
     m_findReferences->findMacroUses(macro);
 }
 
+void CppModelManager::renameMacroUsages(const CPlusPlus::Macro &macro, const QString &replacement)
+{
+    m_findReferences->renameMacroUses(macro, replacement);
+}
+
 CppModelManager::WorkingCopy CppModelManager::buildWorkingCopyList()
 {
     WorkingCopy workingCopy;
@@ -917,11 +942,12 @@ void CppModelManager::updateProjectInfo(const ProjectInfo &pinfo)
 #if 0
     // Tons of debug output...
     qDebug()<<"========= CppModelManager::updateProjectInfo ======";
-    qDebug()<<" for project:"<< pinfo.project.data()->file()->fileName();
-    foreach (const ProjectPart::Ptr &part, pinfo.projectParts) {
+    qDebug()<<" for project:"<< pinfo.project().data()->document()->fileName();
+    foreach (const ProjectPart::Ptr &part, pinfo.projectParts()) {
         qDebug() << "=== part ===";
         qDebug() << "language:" << (part->language == CXX ? "C++" : "ObjC++");
-        qDebug() << "compilerflags:" << part->flags;
+        qDebug() << "C++11:" << part->cxx11Enabled;
+        qDebug() << "Qt version:" << part->qtVersion;
         qDebug() << "precompiled header:" << part->precompiledHeaders;
         qDebug() << "defines:" << part->defines;
         qDebug() << "includes:" << part->includePaths;
@@ -980,7 +1006,7 @@ QFuture<void> CppModelManager::refreshSourceFiles(const QStringList &sourceFiles
     if (! sourceFiles.isEmpty() && m_indexerEnabled) {
         const WorkingCopy workingCopy = buildWorkingCopyList();
 
-        CppPreprocessor *preproc = new CppPreprocessor(this);
+        CppPreprocessor *preproc = new CppPreprocessor(this, m_dumpFileNameWhileParsing);
         preproc->setRevision(++m_revision);
         preproc->setProjectFiles(projectFiles());
         preproc->setIncludePaths(includePaths());
@@ -1108,8 +1134,6 @@ void CppModelManager::updateEditor(Document::Ptr doc)
                 blockRanges.append(TextEditor::BaseTextEditorWidget::BlockRange(block.begin(), block.end()));
             }
 
-            QList<QTextEdit::ExtraSelection> selections;
-
             // set up the format for the errors
             QTextCharFormat errorFormat;
             errorFormat.setUnderlineStyle(QTextCharFormat::WaveUnderline);
@@ -1120,47 +1144,57 @@ void CppModelManager::updateEditor(Document::Ptr doc)
             warningFormat.setUnderlineStyle(QTextCharFormat::WaveUnderline);
             warningFormat.setUnderlineColor(Qt::darkYellow);
 
-            QSet<int> lines;
-            QList<Document::DiagnosticMessage> messages = doc->diagnosticMessages();
-            messages += extraDiagnostics(doc->fileName());
-            foreach (const Document::DiagnosticMessage &m, messages) {
-                if (m.fileName() != fileName)
-                    continue;
-                else if (lines.contains(m.line()))
-                    continue;
-
-                lines.insert(m.line());
-
-                QTextEdit::ExtraSelection sel;
-                if (m.isWarning())
-                    sel.format = warningFormat;
-                else
-                    sel.format = errorFormat;
-
-                QTextCursor c(ed->document()->findBlockByNumber(m.line() - 1));
-                const QString text = c.block().text();
-                for (int i = 0; i < text.size(); ++i) {
-                    if (! text.at(i).isSpace()) {
-                        c.setPosition(c.position() + i);
-                        break;
-                    }
-                }
-                c.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
-                sel.cursor = c;
-                sel.format.setToolTip(m.text());
-                selections.append(sel);
-            }
-
             QList<Editor> todo;
-            foreach (const Editor &e, todo) {
+            foreach (const Editor &e, m_todo) {
                 if (e.textEditor != textEditor)
                     todo.append(e);
             }
-
             Editor e;
+
+            if (m_highlightingFactory->hightlighterHandlesDiagnostics()) {
+                e.updateSelections = false;
+            } else {
+                QSet<int> lines;
+                QList<Document::DiagnosticMessage> messages = doc->diagnosticMessages();
+                messages += extraDiagnostics(doc->fileName());
+                foreach (const Document::DiagnosticMessage &m, messages) {
+                    if (m.fileName() != fileName)
+                        continue;
+                    else if (lines.contains(m.line()))
+                        continue;
+
+                    lines.insert(m.line());
+
+                    QTextEdit::ExtraSelection sel;
+                    if (m.isWarning())
+                        sel.format = warningFormat;
+                    else
+                        sel.format = errorFormat;
+
+                    QTextCursor c(ed->document()->findBlockByNumber(m.line() - 1));
+                    const QString text = c.block().text();
+                    if (m.length() > 0 && m.column() + m.length() < (unsigned)text.size()) {
+                        int column = m.column() > 0 ? m.column() - 1 : 0;
+                        c.setPosition(c.position() + column);
+                        c.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, m.length());
+                    } else {
+                        for (int i = 0; i < text.size(); ++i) {
+                            if (! text.at(i).isSpace()) {
+                                c.setPosition(c.position() + i);
+                                break;
+                            }
+                        }
+                        c.movePosition(QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
+                    }
+                    sel.cursor = c;
+                    sel.format.setToolTip(m.text());
+                    e.selections.append(sel);
+                }
+            }
+
+
             e.revision = ed->document()->revision();
             e.textEditor = textEditor;
-            e.selections = selections;
             e.ifdefedOutBlocks = blockRanges;
             todo.append(e);
             m_todo = todo;
@@ -1189,8 +1223,9 @@ void CppModelManager::updateEditorSelections()
         else if (editor->document()->revision() != ed.revision)
             continue; // outdated
 
-        editor->setExtraSelections(TextEditor::BaseTextEditorWidget::CodeWarningsSelection,
-                                   ed.selections);
+        if (ed.updateSelections)
+            editor->setExtraSelections(TextEditor::BaseTextEditorWidget::CodeWarningsSelection,
+                                       ed.selections);
 
         editor->setIfdefedOutBlocks(ed.ifdefedOutBlocks);
     }
@@ -1362,12 +1397,12 @@ CppCompletionSupport *CppModelManager::completionSupport(Core::IEditor *editor)
 
 void CppModelManager::setCppCompletionAssistProvider(CppCompletionAssistProvider *completionAssistProvider)
 {
-    ExtensionSystem::PluginManager::instance()->removeObject(m_completionAssistProvider);
+    ExtensionSystem::PluginManager::removeObject(m_completionAssistProvider);
     if (completionAssistProvider)
         m_completionAssistProvider = completionAssistProvider;
     else
         m_completionAssistProvider = m_completionFallback;
-    ExtensionSystem::PluginManager::instance()->addObject(m_completionAssistProvider);
+    ExtensionSystem::PluginManager::addObject(m_completionAssistProvider);
 }
 
 CppHighlightingSupport *CppModelManager::highlightingSupport(Core::IEditor *editor) const
