@@ -1,38 +1,36 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef DEBUGGER_ACTIONS_H
 #define DEBUGGER_ACTIONS_H
 
+#include <QObject>
 #include <QHash>
 #include <QMap>
 
@@ -100,6 +98,8 @@ enum DebuggerActionCode
     OperateByInstruction,
     CloseBuffersOnExit,
     SwitchModeOnExit,
+    BreakpointsFullPathByDefault,
+    RaiseOnInterrupt,
 
     UseDebuggingHelpers,
 
@@ -117,11 +117,13 @@ enum DebuggerActionCode
 
     // Gdb
     LoadGdbInit,
+    AttemptQuickStart,
     GdbStartupCommands,
     GdbWatchdogTimeout,
     AutoEnrichParameters,
     UseDynamicType,
     TargetAsync,
+    WarnOnReleaseBuilds,
 
     // Stack
     MaximalStackDepth,
@@ -155,7 +157,7 @@ enum DebuggerActionCode
     BreakOnCatch,
     BreakOnWarning,
     BreakOnFatal,
-    BreakOnRaise,
+    BreakOnAbort,
 
     // Registers
     AlwaysAdjustRegistersColumnWidths,
@@ -167,7 +169,12 @@ enum DebuggerActionCode
     AlwaysAdjustThreadsColumnWidths,
 
     // Modules
-    AlwaysAdjustModulesColumnWidths
+    AlwaysAdjustModulesColumnWidths,
+
+    // QML Tools
+    ShowQmlObjectTree,
+    ShowAppOnTop,
+    QmlUpdateOnSave
 };
 
 } // namespace Internal
