@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef DEBUGGERCORE_H
 #define DEBUGGERCORE_H
@@ -54,6 +51,10 @@ namespace Utils {
 class SavedAction;
 }
 
+namespace ProjectExplorer {
+class RunControl;
+}
+
 namespace Debugger {
 
 class DebuggerEngine;
@@ -85,8 +86,7 @@ public:
     virtual QVariant configValue(const QString &name) const = 0;
     virtual void setConfigValue(const QString &name, const QVariant &value) = 0;
     virtual void updateState(DebuggerEngine *engine) = 0;
-    virtual void updateWatchersWindow() = 0;
-    virtual void showQtDumperLibraryWarning(const QString &details) = 0;
+    virtual void updateWatchersWindow(bool showWatch, bool showReturn) = 0;
     virtual QIcon locationMarkIcon() const = 0;
     virtual const CPlusPlus::Snapshot &cppCodeModelSnapshot() const = 0;
     virtual bool hasSnapshots() const = 0;
@@ -96,8 +96,6 @@ public:
     virtual DebuggerEngine *currentEngine() const = 0;
     virtual bool isActiveDebugLanguage(int language) const = 0;
 
-    virtual void clearCppCodeModelSnapshot() = 0;
-
     // void runTest(const QString &fileName);
     virtual void showMessage(const QString &msg, int channel, int timeout = -1) = 0;
 
@@ -106,19 +104,18 @@ public:
     virtual void runControlFinished(DebuggerEngine *engine) = 0;
     virtual void displayDebugger(DebuggerEngine *engine, bool updateEngine) = 0;
     virtual DebuggerLanguages activeLanguages() const = 0;
-    virtual unsigned enabledEngines() const = 0;
     virtual void synchronizeBreakpoints() = 0;
 
     virtual bool initialize(const QStringList &arguments, QString *errorMessage) = 0;
     virtual QWidget *mainWindow() const = 0;
     virtual bool isDockVisible(const QString &objectName) const = 0;
-    virtual QString debuggerForAbi(const ProjectExplorer::Abi &abi,
-        DebuggerEngineType et = NoEngineType) const = 0;
+//    virtual QString debuggerForAbi(const ProjectExplorer::Abi &abi,
+//        DebuggerEngineType et = NoEngineType) const = 0;
     virtual void showModuleSymbols(const QString &moduleName,
         const QVector<Symbol> &symbols) = 0;
     virtual void openMemoryEditor() = 0;
     virtual void languagesChanged() = 0;
-    virtual void executeDebuggerCommand(const QString &command) = 0;
+    virtual void executeDebuggerCommand(const QString &command, DebuggerLanguages languages) = 0;
     virtual bool evaluateScriptExpression(const QString &expression) = 0;
 
     virtual Utils::SavedAction *action(int code) const = 0;
@@ -128,6 +125,9 @@ public:
 
     virtual DebuggerToolTipManager *toolTipManager() const = 0;
     virtual QSharedPointer<GlobalDebuggerOptions> globalDebuggerOptions() const = 0;
+
+public slots:
+    virtual void attachExternalApplication(ProjectExplorer::RunControl *rc) = 0;
 };
 
 // This is the only way to access the global object.
