@@ -1,36 +1,34 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "debuggertooltipmanager.h"
+#include "debuggerinternalconstants.h"
 #include "watchutils.h"
 #include "debuggerengine.h"
 #include "debuggeractions.h"
@@ -51,29 +49,28 @@
 
 #include <utils/qtcassert.h>
 
-#include <QtGui/QToolButton>
-#include <QtGui/QToolBar>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QStyle>
-#include <QtGui/QIcon>
-#include <QtGui/QApplication>
-#include <QtGui/QMainWindow>
-#include <QtGui/QMoveEvent>
-#include <QtGui/QDesktopWidget>
-#include <QtGui/QScrollBar>
-#include <QtGui/QSortFilterProxyModel>
-#include <QtGui/QStandardItemModel>
-#include <QtGui/QStandardItem>
-#include <QtGui/QPlainTextEdit>
-#include <QtGui/QTextCursor>
-#include <QtGui/QTextDocument>
-#include <QtGui/QLabel>
-#include <QtGui/QClipboard>
+#include <QToolButton>
+#include <QToolBar>
+#include <QVBoxLayout>
+#include <QStyle>
+#include <QIcon>
+#include <QApplication>
+#include <QMoveEvent>
+#include <QDesktopWidget>
+#include <QScrollBar>
+#include <QSortFilterProxyModel>
+#include <QStandardItemModel>
+#include <QStandardItem>
+#include <QPlainTextEdit>
+#include <QTextCursor>
+#include <QTextDocument>
+#include <QLabel>
+#include <QClipboard>
 
-#include <QtCore/QVariant>
-#include <QtCore/QStack>
-#include <QtCore/QDebug>
-#include <QtCore/QTimer>
+#include <QVariant>
+#include <QStack>
+#include <QDebug>
+#include <QTimer>
 
 using namespace Core;
 using namespace TextEditor;
@@ -100,8 +97,8 @@ static const char offsetYAttributeC[] = "offset_y";
 static const char engineTypeAttributeC[] = "engine";
 static const char dateAttributeC[] = "date";
 static const char treeElementC[] = "tree";
-static const char treeModelAttributeC[] = "model"; // Locals/Watches
-static const char treeExpressionAttributeC[] = "expression"; // Locals/Watches
+static const char treeExpressionAttributeC[] = "expression";
+static const char treeInameAttributeC[] = "iname";
 static const char modelElementC[] = "model";
 static const char modelColumnCountAttributeC[] = "columncount";
 static const char modelRowElementC[] = "row";
@@ -209,26 +206,26 @@ class DebuggerToolTipEditor
 {
 public:
     explicit DebuggerToolTipEditor(IEditor *ie = 0);
-    bool isValid() const { return textEditor && baseTextEditor && file; }
+    bool isValid() const { return textEditor && baseTextEditor && document; }
     operator bool() const { return isValid(); }
-    QString fileName() const { return file ? file->fileName() : QString(); }
+    QString fileName() const { return document ? document->fileName() : QString(); }
 
     static DebuggerToolTipEditor currentToolTipEditor();
 
     ITextEditor *textEditor;
     BaseTextEditorWidget *baseTextEditor;
-    IFile *file;
+    IDocument *document;
 };
 
 DebuggerToolTipEditor::DebuggerToolTipEditor(IEditor *ie) :
-    textEditor(0), baseTextEditor(0), file(0)
+    textEditor(0), baseTextEditor(0), document(0)
 {
-    if (ie && ie->file() && isEditorDebuggable(ie)) {
+    if (ie && ie->document() && isEditorDebuggable(ie)) {
         if (ITextEditor *te = qobject_cast<ITextEditor *>(ie)) {
             if (BaseTextEditorWidget *pe = qobject_cast<BaseTextEditorWidget *>(ie->widget())) {
                 textEditor = te;
                 baseTextEditor = pe;
-                file = ie->file();
+                document = ie->document();
             }
         }
     }
@@ -236,7 +233,7 @@ DebuggerToolTipEditor::DebuggerToolTipEditor(IEditor *ie) :
 
 DebuggerToolTipEditor DebuggerToolTipEditor::currentToolTipEditor()
 {
-    if (IEditor *ie = EditorManager::instance()->currentEditor())
+    if (IEditor *ie = EditorManager::currentEditor())
         return DebuggerToolTipEditor(ie);
     return DebuggerToolTipEditor();
 }
@@ -551,9 +548,9 @@ DebuggerToolTipContext::DebuggerToolTipContext() : position(0), line(0), column(
 DebuggerToolTipContext DebuggerToolTipContext::fromEditor(IEditor *ie, int pos)
 {
     DebuggerToolTipContext rc;
-    if (const IFile *file = ie->file()) {
+    if (const IDocument *document = ie->document()) {
         if (const ITextEditor *te = qobject_cast<const ITextEditor *>(ie)) {
-            rc.fileName = file->fileName();
+            rc.fileName = document->fileName();
             rc.position = pos;
             te->convertPosition(pos, &rc.line, &rc.column);
         }
@@ -617,7 +614,6 @@ DebuggerToolTipWidget::DebuggerToolTipWidget(QWidget *parent) :
     m_titleLabel(new DraggableLabel),
     m_engineAcquired(false),
     m_creationDate(QDate::currentDate()),
-    m_debuggerModel(TooltipsWatch),
     m_treeView(new DebuggerToolTipTreeView),
     m_defaultModel(new QStandardItemModel(this))
 {
@@ -664,7 +660,7 @@ bool DebuggerToolTipWidget::matches(const QString &fileName,
     return function == m_context.function;
 }
 
-void DebuggerToolTipWidget::acquireEngine(Debugger::DebuggerEngine *engine)
+void DebuggerToolTipWidget::acquireEngine(DebuggerEngine *engine)
 {
     QTC_ASSERT(engine, return);
 
@@ -694,9 +690,7 @@ void DebuggerToolTipWidget::copy()
 {
     const QString clipboardText = clipboardContents();
     QClipboard *clipboard = QApplication::clipboard();
-#ifdef Q_WS_X11
     clipboard->setText(clipboardText, QClipboard::Selection);
-#endif
     clipboard->setText(clipboardText, QClipboard::Clipboard);
 }
 
@@ -794,7 +788,7 @@ DebuggerToolTipWidget *DebuggerToolTipWidget::loadSessionDataI(QXmlStreamReader
     if (debugToolTips)
         qDebug() << "Creating tooltip " << context <<  " from " << creationDate << offset;
     DebuggerToolTipWidget *rc = 0;
-    if (className == "Debugger::Internal::DebuggerToolTipWidget")
+    if (className == QLatin1String("Debugger::Internal::DebuggerToolTipWidget"))
         rc = new DebuggerToolTipWidget;
     if (rc) {
         rc->setContext(context);
@@ -816,7 +810,7 @@ void DebuggerToolTipWidget::saveSessionData(QXmlStreamWriter &w) const
 {
     w.writeStartElement(QLatin1String(toolTipElementC));
     QXmlStreamAttributes attributes;
-    attributes.append(QLatin1String(toolTipClassAttributeC), QString::fromAscii(metaObject()->className()));
+    attributes.append(QLatin1String(toolTipClassAttributeC), QString::fromLatin1(metaObject()->className()));
     attributes.append(QLatin1String(fileNameAttributeC), m_context.fileName);
     if (!m_context.function.isEmpty())
         attributes.append(QLatin1String(functionAttributeC), m_context.function);
@@ -836,61 +830,46 @@ void DebuggerToolTipWidget::saveSessionData(QXmlStreamWriter &w) const
 }
 
 /*!
-    \class Debugger::Internal::DebuggerToolTipExpressionFilterModel
+    \class Debugger::Internal::TooltipFilterModel
 
-    \brief Model for tooltips filtering a local variable using the locals or tooltip model,
-    matching on the name.
-
-    Expressions/names can either be flat ('foo' will match at the root level)
-    or nested ('this.m_foo' will match 'this' at root level and 'm_foo' at level 1).
+    \brief Model for tooltips filtering an item on the watchhandler matching its tree on the iname.
 
     In addition, suppress the model's tooltip data to avoid a tooltip on a tooltip.
 */
 
-class DebuggerToolTipExpressionFilterModel : public QSortFilterProxyModel
+class TooltipFilterModel : public QSortFilterProxyModel
 {
 public:
-    explicit DebuggerToolTipExpressionFilterModel(QAbstractItemModel *model, const QString &exp, QObject *parent = 0);
-    virtual bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
+    TooltipFilterModel(QAbstractItemModel *model, const QByteArray &iname)
+        : m_iname(iname)
+    {
+        setSourceModel(model);
+    }
 
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const
+    {
+        return role == Qt::ToolTipRole
+            ? QVariant() : QSortFilterProxyModel::data(index, role);
+    }
+
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
 
 private:
-    const QStringList m_expressions;
+    const QByteArray m_iname;
 };
 
-DebuggerToolTipExpressionFilterModel::DebuggerToolTipExpressionFilterModel(QAbstractItemModel *model,
-                                                                           const QString &exp,
-                                                                           QObject *parent) :
-    QSortFilterProxyModel(parent),
-    m_expressions(exp.split(QLatin1Char('.')))
+static bool isSubIname(const QByteArray &haystack, const QByteArray &needle)
 {
-    setSourceModel(model);
+    return haystack.size() > needle.size()
+           && haystack.startsWith(needle)
+           && haystack.at(needle.size()) == '.';
 }
 
-QVariant DebuggerToolTipExpressionFilterModel::data(const QModelIndex &index, int role) const
+bool TooltipFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
-    return role != Qt::ToolTipRole ?
-        QSortFilterProxyModel::data(index, role) : QVariant();
-}
-
-// Return depth of a model index, that is, 0 for root index, 1 for level-1 children, etc.
-static inline int indexDepth(QModelIndex index)
-{
-    int depth = 0;
-    for ( ; index.isValid() ; index = index.parent())
-        depth++;
-    return depth;
-}
-
-bool DebuggerToolTipExpressionFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
-{
-    // Match on expression for top level, else pass through.
-    const int depth = indexDepth(sourceParent);
-    if (depth >= m_expressions.size()) // No filters at this level
-        return true;
     const QModelIndex nameIndex = sourceModel()->index(sourceRow, 0, sourceParent);
-    return nameIndex.data().toString() == m_expressions.at(depth);
+    const QByteArray iname = nameIndex.data(LocalsINameRole).toByteArray();
+    return iname == m_iname || isSubIname(iname, m_iname) || isSubIname(m_iname, iname);
 }
 
 /*!
@@ -905,6 +884,7 @@ DebuggerToolTipTreeView::DebuggerToolTipTreeView(QWidget *parent) :
     QTreeView(parent)
 {
     setHeaderHidden(true);
+    setEditTriggers(NoEditTriggers);
 
     setUniformRowHeights(true);
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -923,6 +903,7 @@ QAbstractItemModel *DebuggerToolTipTreeView::swapModel(QAbstractItemModel *newMo
         if (previousModel)
             previousModel->disconnect(SIGNAL(rowsInserted(QModelIndex,int,int)), this);
         setModel(newModel);
+        //setRootIndex(newModel->index(0, 0));
         connect(newModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
                 this, SLOT(computeSize()), Qt::QueuedConnection);
         computeSize();
@@ -990,24 +971,12 @@ void DebuggerToolTipTreeView::computeSize()
     setRootIsDecorated(rootDecorated);
 }
 
-void DebuggerToolTipWidget::doAcquireEngine(Debugger::DebuggerEngine *engine)
+void DebuggerToolTipWidget::doAcquireEngine(DebuggerEngine *engine)
 {
     // Create a filter model on the debugger's model and switch to it.
-    QAbstractItemModel *model = 0;
-    switch (m_debuggerModel) {
-    case LocalsWatch:
-        model = engine->localsModel();
-        break;
-    case WatchersWatch:
-        model = engine->watchersModel();
-        break;
-    case TooltipsWatch:
-        model = engine->toolTipsModel();
-        break;
-    }
-    QTC_ASSERT(model, return);
-    DebuggerToolTipExpressionFilterModel *filterModel =
-            new DebuggerToolTipExpressionFilterModel(model, m_expression);
+    QAbstractItemModel *model = engine->watchModel();
+    TooltipFilterModel *filterModel =
+            new TooltipFilterModel(model, m_iname);
     swapModel(filterModel);
 }
 
@@ -1016,7 +985,7 @@ QAbstractItemModel *DebuggerToolTipWidget::swapModel(QAbstractItemModel *newMode
     QAbstractItemModel *oldModel = m_treeView->swapModel(newModel);
     // When looking at some 'this.m_foo.x', expand all items
     if (newModel) {
-        if (const int level = m_expression.count(QLatin1Char('.'))) {
+        if (const int level = m_iname.count('.')) {
             QModelIndex index = newModel->index(0, 0);
             for (int i = 0; i < level && index.isValid(); i++, index = index.child(0, 0))
                 m_treeView->setExpanded(index, true);
@@ -1078,8 +1047,9 @@ void DebuggerToolTipWidget::doSaveSessionData(QXmlStreamWriter &w) const
 {
     w.writeStartElement(QLatin1String(treeElementC));
     QXmlStreamAttributes attributes;
-    attributes.append(QLatin1String(treeModelAttributeC), QString::number(m_debuggerModel));
-    attributes.append(QLatin1String(treeExpressionAttributeC), m_expression);
+    if (!m_expression.isEmpty())
+        attributes.append(QLatin1String(treeExpressionAttributeC), m_expression);
+    attributes.append(QLatin1String(treeInameAttributeC), QLatin1String(m_iname));
     w.writeAttributes(attributes);
     if (QAbstractItemModel *model = m_treeView->model()) {
         XmlWriterTreeModelVisitor v(model, w);
@@ -1094,11 +1064,11 @@ void DebuggerToolTipWidget::doLoadSessionData(QXmlStreamReader &r)
         return;
     // Restore data to default model and show that.
     const QXmlStreamAttributes attributes = r.attributes();
-    m_debuggerModel = attributes.value(QLatin1String(treeModelAttributeC)).toString().toInt();
+    m_iname = attributes.value(QLatin1String(treeInameAttributeC)).toString().toLatin1();
     m_expression = attributes.value(QLatin1String(treeExpressionAttributeC)).toString();
     if (debugToolTips)
-        qDebug() << "DebuggerTreeViewToolTipWidget::doLoadSessionData() " << m_debuggerModel << m_expression;
-    setObjectName(QLatin1String("DebuggerTreeViewToolTipWidget: ") + m_expression);
+        qDebug() << "DebuggerTreeViewToolTipWidget::doLoadSessionData() " << m_debuggerModel << m_iname;
+    setObjectName(QLatin1String("DebuggerTreeViewToolTipWidget: ") + QLatin1String(m_iname));
     restoreTreeModel(r, m_defaultModel);
     r.readNext(); // Skip </tree>
     m_treeView->swapModel(m_defaultModel);
@@ -1310,7 +1280,7 @@ void DebuggerToolTipManager::slotUpdateVisibleToolTips()
     }
 }
 
-void DebuggerToolTipManager::slotDebuggerStateChanged(Debugger::DebuggerState state)
+void DebuggerToolTipManager::slotDebuggerStateChanged(DebuggerState state)
 {
     const QObject *engine = sender();
     QTC_ASSERT(engine, return);
@@ -1318,7 +1288,7 @@ void DebuggerToolTipManager::slotDebuggerStateChanged(Debugger::DebuggerState st
     const QString name = engine->objectName();
     if (debugToolTips)
         qDebug() << "DebuggerToolTipWidget::debuggerStateChanged"
-                 << engine << Debugger::DebuggerEngine::stateName(state);
+                 << engine << DebuggerEngine::stateName(state);
 
     // Release at earliest possible convenience.
     switch (state) {
@@ -1407,7 +1377,7 @@ void DebuggerToolTipManager::debugModeEntered()
     // Hook up all signals in debug mode.
     if (!m_debugModeActive) {
         m_debugModeActive = true;
-        QWidget *topLevel = ICore::instance()->mainWindow()->topLevelWidget();
+        QWidget *topLevel = ICore::mainWindow()->topLevelWidget();
         topLevel->installEventFilter(this);
         EditorManager *em = EditorManager::instance();
         connect(em, SIGNAL(currentEditorChanged(Core::IEditor*)),
@@ -1431,7 +1401,7 @@ void DebuggerToolTipManager::leavingDebugMode()
     if (m_debugModeActive) {
         m_debugModeActive = false;
         hide();
-        if (QWidget *topLevel = ICore::instance()->mainWindow()->topLevelWidget())
+        if (QWidget *topLevel = ICore::mainWindow()->topLevelWidget())
             topLevel->removeEventFilter(this);
         if (EditorManager *em = EditorManager::instance()) {
             foreach (IEditor *e, em->openedEditors()) {
@@ -1496,14 +1466,16 @@ void DebuggerToolTipManager::slotTooltipOverrideRequested(ITextEditor *editor,
         qDebug() << "<slotTooltipOverrideRequested() " << currentEngine << *handled;
 }
 
-QStringList DebuggerToolTipManager::treeWidgetExpressions(const QString &fileName,
-                                                          const QString &engineType,
-                                                          const QString &function) const
+
+DebuggerToolTipManager::ExpressionInamePairs
+    DebuggerToolTipManager::treeWidgetExpressions(const QString &fileName,
+                                                  const QString &engineType,
+                                                  const QString &function) const
 {
-    QStringList rc;
+    ExpressionInamePairs rc;
     foreach (const QPointer<DebuggerToolTipWidget> &tw, m_tooltips) {
         if (!tw.isNull() && tw->matches(fileName, engineType, function))
-            rc.push_back(tw->expression());
+            rc.push_back(ExpressionInamePair(tw->expression(), tw->iname()));
     }
     if (debugToolTips)
         qDebug() << "DebuggerToolTipManager::treeWidgetExpressions"
