@@ -1,42 +1,39 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef REMOTEGDBPROCESS_H
 #define REMOTEGDBPROCESS_H
 
 #include "abstractgdbprocess.h"
 
-#include <utils/ssh/sshconnection.h>
-#include <utils/ssh/sshremoteprocess.h>
+#include <ssh/sshconnection.h>
+#include <ssh/sshremoteprocess.h>
 
 #include <QByteArray>
 #include <QQueue>
@@ -44,14 +41,14 @@
 namespace Debugger {
 namespace Internal {
 
-class RemotePlainGdbAdapter;
+class GdbRemotePlainEngine;
 
 class RemoteGdbProcess : public AbstractGdbProcess
 {
     Q_OBJECT
 public:
-    RemoteGdbProcess(const Utils::SshConnectionParameters &server,
-                     RemotePlainGdbAdapter *adapter, QObject *parent = 0);
+    RemoteGdbProcess(const QSsh::SshConnectionParameters &server,
+                     GdbRemotePlainEngine *adapter, QObject *parent = 0);
 
     virtual QByteArray readAllStandardOutput();
     virtual QByteArray readAllStandardError();
@@ -106,11 +103,11 @@ private:
     void emitErrorExit(const QString &error);
     void setState(State newState);
 
-    Utils::SshConnectionParameters m_connParams;
-    Utils::SshConnection::Ptr m_conn;
-    Utils::SshRemoteProcess::Ptr m_gdbProc;
-    Utils::SshRemoteProcess::Ptr m_appOutputReader;
-    Utils::SshRemoteProcess::Ptr m_fifoCreator;
+    QSsh::SshConnectionParameters m_connParams;
+    QSsh::SshConnection *m_conn;
+    QSsh::SshRemoteProcess::Ptr m_gdbProc;
+    QSsh::SshRemoteProcess::Ptr m_appOutputReader;
+    QSsh::SshRemoteProcess::Ptr m_fifoCreator;
     QByteArray m_gdbOutput;
     QByteArray m_errorOutput;
     QString m_command;
@@ -123,7 +120,7 @@ private:
     QByteArray m_appOutputFileName;
     State m_state;
 
-    RemotePlainGdbAdapter *m_adapter;
+    GdbRemotePlainEngine *m_adapter;
 };
 
 } // namespace Internal
