@@ -1,33 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
+** This file is part of Qt Creator.
 **
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef WATCHUTILS_H
 #define WATCHUTILS_H
@@ -72,7 +70,17 @@ enum DebuggerEncoding
     Hex2EncodedLocal8BitWithQuotes         = 13,
     JulianDate                             = 14,
     MillisecondsSinceMidnight              = 15,
-    JulianDateAndMillisecondsSinceMidnight = 16
+    JulianDateAndMillisecondsSinceMidnight = 16,
+    Hex2EncodedInt1                        = 17,
+    Hex2EncodedInt2                        = 18,
+    Hex2EncodedInt4                        = 19,
+    Hex2EncodedInt8                        = 20,
+    Hex2EncodedUInt1                       = 21,
+    Hex2EncodedUInt2                       = 22,
+    Hex2EncodedUInt4                       = 23,
+    Hex2EncodedUInt8                       = 24,
+    Hex2EncodedFloat4                      = 25,
+    Hex2EncodedFloat8                      = 26
 };
 
 bool isEditorDebuggable(Core::IEditor *editor);
@@ -92,7 +100,8 @@ QByteArray gdbQuoteTypes(const QByteArray &type);
 bool isFloatType(const QByteArray &type);
 bool isIntOrFloatType(const QByteArray &type);
 bool isIntType(const QByteArray &type);
-bool isSymbianIntType(const QByteArray &type);
+
+QString formatToolTipAddress(quint64 a);
 
 QString quoteUnprintableLatin1(const QByteArray &ba);
 
@@ -100,9 +109,13 @@ QString quoteUnprintableLatin1(const QByteArray &ba);
 bool isCppEditor(Core::IEditor *editor);
 QString cppExpressionAt(TextEditor::ITextEditor *editor, int pos,
                         int *line, int *column, QString *function = 0);
+QString fixCppExpression(const QString &exp);
 QString cppFunctionAt(const QString &fileName, int line);
 // Decode string data as returned by the dumper helpers.
 QString decodeData(const QByteArray &baIn, int encoding);
+// Decode string data as returned by the dumper helpers.
+void decodeArray(WatchData *list, const WatchData &tmplate,
+    const QByteArray &rawData, int encoding);
 
 // Get variables that are not initialized at a certain line
 // of a function from the code model. Shadowed variables will
