@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "fakevimplugin.h"
 
@@ -78,8 +75,6 @@
 #include <utils/treewidgetcolumnstretcher.h>
 #include <utils/stylehelper.h>
 
-#include <cppeditor/cppeditorconstants.h>
-
 #include <cpptools/cpptoolsconstants.h>
 
 #include <QAbstractTableModel>
@@ -100,29 +95,19 @@
 #include <QTextEdit>
 #include <QTreeWidgetItem>
 
-using namespace FakeVim::Internal;
 using namespace TextEditor;
 using namespace Core;
 
 namespace FakeVim {
-namespace Constants {
+namespace Internal {
 
 const char INSTALL_HANDLER[]                = "TextEditor.FakeVimHandler";
-const char MINI_BUFFER[]                    = "TextEditor.FakeVimMiniBuffer";
-const char INSTALL_KEY[]                    = "Alt+V,Alt+V";
 const char SETTINGS_CATEGORY[]              = "D.FakeVim";
 const char SETTINGS_CATEGORY_FAKEVIM_ICON[] = ":/core/images/category_fakevim.png";
 const char SETTINGS_ID[]                    = "A.General";
 const char SETTINGS_EX_CMDS_ID[]            = "B.ExCommands";
 const char SETTINGS_USER_CMDS_ID[]          = "C.UserCommands";
 
-} // namespace Constants
-} // namespace FakeVim
-
-
-namespace FakeVim {
-namespace Internal {
-
 class MiniBuffer : public QLabel
 {
     Q_OBJECT
@@ -178,20 +163,19 @@ typedef QMap<QString, QRegExp> ExCommandMap;
 typedef QMap<int, QString> UserCommandMap;
 typedef QLatin1String _;
 
-class FakeVimOptionPage : public Core::IOptionsPage
+class FakeVimOptionPage : public IOptionsPage
 {
     Q_OBJECT
 
 public:
-    FakeVimOptionPage() {}
-
-    // IOptionsPage
-    QString id() const { return _(Constants::SETTINGS_ID); }
-    QString displayName() const { return tr("General"); }
-    QString category() const { return _(Constants::SETTINGS_CATEGORY); }
-    QString displayCategory() const { return tr("FakeVim"); }
-    QIcon categoryIcon() const
-        { return QIcon(_(Constants::SETTINGS_CATEGORY_FAKEVIM_ICON)); }
+    FakeVimOptionPage()
+    {
+        setId(_(SETTINGS_ID));
+        setDisplayName(tr("General"));
+        setCategory(_(SETTINGS_CATEGORY));
+        setDisplayCategory(tr("FakeVim"));
+        setCategoryIcon(_(SETTINGS_CATEGORY_FAKEVIM_ICON));
+    }
 
     QWidget *createPage(QWidget *parent);
     void apply() { m_group.apply(ICore::settings()); }
@@ -251,6 +235,8 @@ QWidget *FakeVimOptionPage::createPage(QWidget *parent)
         m_ui.checkBoxIncSearch);
     m_group.insert(theFakeVimSetting(ConfigUseCoreSearch),
         m_ui.checkBoxUseCoreSearch);
+    m_group.insert(theFakeVimSetting(ConfigSmartCase),
+        m_ui.checkBoxSmartCase);
 
     connect(m_ui.pushButtonCopyTextEditorSettings, SIGNAL(clicked()),
         SLOT(copyTextEditorSettings()));
@@ -272,6 +258,7 @@ QWidget *FakeVimOptionPage::createPage(QWidget *parent)
                 << sep << m_ui.checkBoxIncSearch->text()
                 << sep << m_ui.checkBoxStartOfLine->text()
                 << sep << m_ui.checkBoxUseCoreSearch->text()
+                << sep << m_ui.checkBoxSmartCase->text()
                 << sep << m_ui.checkBoxShowMarks->text()
                 << sep << m_ui.checkBoxPassControlKey->text()
                 << sep << m_ui.labelShiftWidth->text()
@@ -336,20 +323,20 @@ bool FakeVimOptionPage::matches(const QString &s) const
 
 enum { CommandRole = Qt::UserRole };
 
-class FakeVimExCommandsPage : public Core::CommandMappings
+class FakeVimExCommandsPage : public CommandMappings
 {
     Q_OBJECT
 
 public:
-    FakeVimExCommandsPage(FakeVimPluginPrivate *q) : m_q(q) {}
-    ~FakeVimExCommandsPage() {}
-
-    // IOptionsPage
-    QString id() const { return _(Constants::SETTINGS_EX_CMDS_ID); }
-    QString displayName() const { return tr("Ex Command Mapping"); }
-    QString category() const { return _(Constants::SETTINGS_CATEGORY); }
-    QString displayCategory() const { return tr("FakeVim"); }
-    QIcon categoryIcon() const { return QIcon(); } // TODO: Icon for FakeVim
+    FakeVimExCommandsPage(FakeVimPluginPrivate *q)
+        : m_q(q)
+    {
+        setId(_(SETTINGS_EX_CMDS_ID));
+        setDisplayName(tr("Ex Command Mapping"));
+        setCategory(_(SETTINGS_CATEGORY));
+        setDisplayCategory(tr("FakeVim"));
+        setCategoryIcon(_(SETTINGS_CATEGORY_FAKEVIM_ICON));
+    }
 
     QWidget *createPage(QWidget *parent);
     void initialize();
@@ -380,12 +367,9 @@ QWidget *FakeVimExCommandsPage::createPage(QWidget *parent)
 
 void FakeVimExCommandsPage::initialize()
 {
-    ActionManager *am = ICore::actionManager();
-    QTC_ASSERT(am, return);
-
     QMap<QString, QTreeWidgetItem *> sections;
 
-    foreach (Command *c, am->commands()) {
+    foreach (Command *c, ActionManager::commands()) {
         if (c->action() && c->action()->isSeparator())
             continue;
 
@@ -561,20 +545,21 @@ public:
     }
 };
 
-class FakeVimUserCommandsPage : public Core::IOptionsPage
+class FakeVimUserCommandsPage : public IOptionsPage
 {
     Q_OBJECT
 
 public:
-    FakeVimUserCommandsPage(FakeVimPluginPrivate *q) : m_q(q) {}
-    ~FakeVimUserCommandsPage() {}
+    FakeVimUserCommandsPage(FakeVimPluginPrivate *q)
+        : m_q(q)
+    {
+        setId(_(SETTINGS_USER_CMDS_ID));
+        setDisplayName(tr("User Command Mapping"));
+        setCategory(_(SETTINGS_CATEGORY));
+        setDisplayCategory(tr("FakeVim"));
+        setCategoryIcon(_(SETTINGS_CATEGORY_FAKEVIM_ICON));
+    }
 
-    // IOptionsPage
-    QString id() const { return _(Constants::SETTINGS_USER_CMDS_ID); }
-    QString displayName() const { return tr("User Command Mapping"); }
-    QString category() const { return _(Constants::SETTINGS_CATEGORY); }
-    QString displayCategory() const { return tr("FakeVim"); }
-    QIcon categoryIcon() const { return QIcon(); }
     void apply();
     void finish() {}
 
@@ -618,15 +603,15 @@ void FakeVimUserCommandsPage::apply()
 //
 ///////////////////////////////////////////////////////////////////////
 
-class FakeVimCompletionAssistProvider : public TextEditor::CompletionAssistProvider
+class FakeVimCompletionAssistProvider : public CompletionAssistProvider
 {
 public:
-    bool supportsEditor(const Core::Id &) const
+    bool supportsEditor(const Id &) const
     {
         return false;
     }
 
-    TextEditor::IAssistProcessor *createProcessor() const;
+    IAssistProcessor *createProcessor() const;
 
     void setActive(const QString &needle, bool forward, FakeVimHandler *handler)
     {
@@ -716,11 +701,11 @@ public:
 class FakeVimCompletionAssistProcessor : public IAssistProcessor
 {
 public:
-    FakeVimCompletionAssistProcessor(const TextEditor::IAssistProvider *provider)
+    FakeVimCompletionAssistProcessor(const IAssistProvider *provider)
         : m_provider(static_cast<const FakeVimCompletionAssistProvider *>(provider))
     {}
 
-    virtual TextEditor::IAssistProposal *perform(const IAssistInterface *interface)
+    IAssistProposal *perform(const IAssistInterface *interface)
     {
         const QString &needle = m_provider->needle();
 
@@ -833,10 +818,10 @@ private:
     FakeVimOptionPage *m_fakeVimOptionsPage;
     FakeVimExCommandsPage *m_fakeVimExCommandsPage;
     FakeVimUserCommandsPage *m_fakeVimUserCommandsPage;
-    QHash<Core::IEditor *, FakeVimHandler *> m_editorToHandler;
+    QHash<IEditor *, FakeVimHandler *> m_editorToHandler;
 
-    void triggerAction(const Core::Id &id);
-    void setActionChecked(const Core::Id &id, bool check);
+    void triggerAction(const Id &id);
+    void setActionChecked(const Id &id, bool check);
 
     typedef int (*DistFunction)(const QRect &cursor, const QRect &other);
     void moveSomewhere(DistFunction f);
@@ -851,7 +836,7 @@ private:
     UserCommandMap m_userCommandMap;
     UserCommandMap m_defaultUserCommandMap;
 
-    Core::StatusBarWidget *m_statusBar;
+    StatusBarWidget *m_statusBar;
     // @TODO: Delete
     //WordCompletion *m_wordCompletion;
     FakeVimCompletionAssistProvider *m_wordProvider;
@@ -895,7 +880,7 @@ FakeVimPluginPrivate::FakeVimPluginPrivate(FakeVimPlugin *plugin)
         QRegExp("^(cN(ext)?|cp(revious)?)!?( (.*))?$");
     defaultExCommandMap()["Coreplugin.OutputPane.nextitem"] =
         QRegExp("^cn(ext)?!?( (.*))?$");
-    defaultExCommandMap()[CppEditor::Constants::JUMP_TO_DEFINITION] =
+    defaultExCommandMap()[TextEditor::Constants::FOLLOW_SYMBOL_UNDER_CURSOR] =
         QRegExp("^tag?$");
     defaultExCommandMap()[Core::Constants::GO_BACK] =
         QRegExp("^pop?$");
@@ -940,8 +925,6 @@ void FakeVimPluginPrivate::aboutToShutdown()
 bool FakeVimPluginPrivate::initialize()
 {
     EditorManager *editorManager = ICore::editorManager();
-    ActionManager *actionManager = ICore::actionManager();
-    QTC_ASSERT(actionManager, return false);
 
     //m_wordCompletion = new WordCompletion;
     //q->addAutoReleasedObject(m_wordCompletion);
@@ -970,13 +953,13 @@ bool FakeVimPluginPrivate::initialize()
 
     readSettings();
 
-    Core::Command *cmd = 0;
-    cmd = actionManager->registerAction(theFakeVimSetting(ConfigUseFakeVim),
-        Constants::INSTALL_HANDLER, globalcontext, true);
-    cmd->setDefaultKeySequence(QKeySequence(Constants::INSTALL_KEY));
+    Command *cmd = 0;
+    cmd = ActionManager::registerAction(theFakeVimSetting(ConfigUseFakeVim),
+        INSTALL_HANDLER, globalcontext, true);
+    cmd->setDefaultKeySequence(QKeySequence(UseMacShortcuts ? tr("Meta+V,Meta+V") : tr("Alt+V,Alt+V")));
 
     ActionContainer *advancedMenu =
-        actionManager->actionContainer(Core::Constants::M_EDIT_ADVANCED);
+        ActionManager::actionContainer(Core::Constants::M_EDIT_ADVANCED);
     advancedMenu->addAction(cmd, Core::Constants::G_EDIT_EDITOR);
 
     for (int i = 1; i < 10; ++i) {
@@ -984,9 +967,8 @@ bool FakeVimPluginPrivate::initialize()
         act->setText(tr("Execute User Action #%1").arg(i));
         act->setData(i);
         QString id = QString("FakeVim.UserAction%1").arg(i);
-        QString keys = QString("Alt+V,%1").arg(i);
-        cmd = actionManager->registerAction(act, Core::Id(id), globalcontext);
-        cmd->setDefaultKeySequence(QKeySequence(keys));
+        cmd = ActionManager::registerAction(act, Id(id), globalcontext);
+        cmd->setDefaultKeySequence(QKeySequence((UseMacShortcuts ? tr("Meta+V,%1") : tr("Alt+V,%1")).arg(i)));
         connect(act, SIGNAL(triggered()), SLOT(userActionTriggered()));
     }
 
@@ -1023,17 +1005,18 @@ void FakeVimPluginPrivate::userActionTriggered()
     if (!key)
         return;
     QString cmd = userCommandMap().value(key);
-    IEditor *editor = ICore::editorManager()->currentEditor();
+    IEditor *editor = EditorManager::currentEditor();
     FakeVimHandler *handler = m_editorToHandler[editor];
     if (handler)
         handler->handleInput(cmd);
 }
 
-static const char exCommandMapGroup[] = "FakeVimExCommand";
-static const char userCommandMapGroup[] = "FakeVimUserCommand";
-static const char reKey[] = "RegEx";
-static const char cmdKey[] = "Cmd";
-static const char idKey[] = "Command";
+
+const char exCommandMapGroup[] = "FakeVimExCommand";
+const char userCommandMapGroup[] = "FakeVimUserCommand";
+const char reKey[] = "RegEx";
+const char cmdKey[] = "Cmd";
+const char idKey[] = "Command";
 
 void FakeVimPluginPrivate::writeSettings()
 {
@@ -1131,16 +1114,12 @@ void FakeVimPluginPrivate::maybeReadVimRc()
 
 void FakeVimPluginPrivate::showSettingsDialog()
 {
-    ICore::showOptionsDialog(
-        _(Constants::SETTINGS_CATEGORY),
-        _(Constants::SETTINGS_ID));
+    ICore::showOptionsDialog(_(SETTINGS_CATEGORY), _(SETTINGS_ID));
 }
 
 void FakeVimPluginPrivate::triggerAction(const Id &id)
 {
-    Core::ActionManager *am = ICore::actionManager();
-    QTC_ASSERT(am, return);
-    Core::Command *cmd = am->command(id);
+    Core::Command *cmd = ActionManager::command(id);
     QTC_ASSERT(cmd, qDebug() << "UNKNOWN CODE: " << id.name(); return);
     QAction *action = cmd->action();
     QTC_ASSERT(action, return);
@@ -1149,9 +1128,7 @@ void FakeVimPluginPrivate::triggerAction(const Id &id)
 
 void FakeVimPluginPrivate::setActionChecked(const Id &id, bool check)
 {
-    Core::ActionManager *am = ICore::actionManager();
-    QTC_ASSERT(am, return);
-    Core::Command *cmd = am->command(id);
+    Core::Command *cmd = ActionManager::command(id);
     QTC_ASSERT(cmd, return);
     QAction *action = cmd->action();
     QTC_ASSERT(action, return);
@@ -1257,11 +1234,9 @@ void FakeVimPluginPrivate::windowCommand(int key)
 
 void FakeVimPluginPrivate::moveSomewhere(DistFunction f)
 {
-    EditorManager *editorManager = ICore::editorManager();
-    IEditor *editor = editorManager->currentEditor();
+    IEditor *editor = EditorManager::currentEditor();
     QWidget *w = editor->widget();
-    QPlainTextEdit *pe =
-        qobject_cast<QPlainTextEdit *>(editor->widget());
+    QPlainTextEdit *pe = qobject_cast<QPlainTextEdit *>(w);
     QTC_ASSERT(pe, return);
     QRect rc = pe->cursorRect();
     QRect cursorRect(w->mapToGlobal(rc.topLeft()),
@@ -1271,8 +1246,7 @@ void FakeVimPluginPrivate::moveSomewhere(DistFunction f)
     IEditor *bestEditor = 0;
     int bestValue = 1 << 30;
 
-    QList<IEditor*> editors = editorManager->visibleEditors();
-    foreach (IEditor *editor, editors) {
+    foreach (IEditor *editor, EditorManager::instance()->visibleEditors()) {
         QWidget *w = editor->widget();
         QRect editorRect(w->mapToGlobal(w->geometry().topLeft()),
                 w->mapToGlobal(w->geometry().bottomRight()));
@@ -1290,7 +1264,7 @@ void FakeVimPluginPrivate::moveSomewhere(DistFunction f)
     // FIME: This is know to fail as the EditorManager will fall back to
     // the current editor's view. Needs additional public API there.
     if (bestEditor)
-        editorManager->activateEditor(bestEditor);
+        EditorManager::activateEditor(bestEditor);
 }
 
 void FakeVimPluginPrivate::find(bool reverse)
@@ -1333,7 +1307,7 @@ public:
     }
 };
 
-void FakeVimPluginPrivate::editorOpened(Core::IEditor *editor)
+void FakeVimPluginPrivate::editorOpened(IEditor *editor)
 {
     if (!editor)
         return;
@@ -1398,7 +1372,7 @@ void FakeVimPluginPrivate::editorOpened(Core::IEditor *editor)
     }
 }
 
-void FakeVimPluginPrivate::editorAboutToClose(Core::IEditor *editor)
+void FakeVimPluginPrivate::editorAboutToClose(IEditor *editor)
 {
     //qDebug() << "CLOSING: " << editor << editor->widget();
     m_editorToHandler.remove(editor);
@@ -1417,18 +1391,18 @@ void FakeVimPluginPrivate::setUseFakeVimInternal(bool on)
 {
     if (on) {
         //ICore *core = ICore::instance();
-        //core->updateAdditionalContexts(Core::Context(FAKEVIM_CONTEXT),
-        // Core::Context());
-        foreach (Core::IEditor *editor, m_editorToHandler.keys())
+        //core->updateAdditionalContexts(Context(FAKEVIM_CONTEXT),
+        // Context());
+        foreach (IEditor *editor, m_editorToHandler.keys())
             m_editorToHandler[editor]->setupWidget();
     } else {
         //ICore *core = ICore::instance();
-        //core->updateAdditionalContexts(Core::Context(),
-        // Core::Context(FAKEVIM_CONTEXT));
+        //core->updateAdditionalContexts(Context(),
+        // Context(FAKEVIM_CONTEXT));
         showCommandBuffer(QString(), -1);
-        foreach (Core::IEditor *editor, m_editorToHandler.keys()) {
-            if (TextEditor::BaseTextEditorWidget *textEditor =
-                    qobject_cast<TextEditor::BaseTextEditorWidget *>(editor->widget())) {
+        foreach (IEditor *editor, m_editorToHandler.keys()) {
+            if (BaseTextEditorWidget *textEditor =
+                    qobject_cast<BaseTextEditorWidget *>(editor->widget())) {
                 m_editorToHandler[editor]->restoreWidget(textEditor->tabSettings().m_tabSize);
             }
         }
@@ -1493,7 +1467,7 @@ void FakeVimPluginPrivate::handleExCommand(bool *handled, const ExCommand &cmd)
     *handled = true;
     if (cmd.matches("w", "write") || cmd.cmd == "wq") {
         // :w[rite]
-        Core::IEditor *editor = m_editorToHandler.key(handler);
+        IEditor *editor = m_editorToHandler.key(handler);
         const QString fileName = handler->currentFileName();
         if (editor && editor->document()->fileName() == fileName) {
             // Handle that as a special case for nicer interaction with core
@@ -1574,7 +1548,7 @@ void FakeVimPluginPrivate::handleExCommand(bool *handled, const ExCommand &cmd)
         const Iterator end = exCommandMap().constEnd();
         for (Iterator it = exCommandMap().constBegin(); it != end; ++it) {
             const QString &id = it.key();
-            const QRegExp &re = it.value();
+            QRegExp re = it.value();
             if (!re.pattern().isEmpty() && re.indexIn(cmd.cmd) != -1) {
                 triggerAction(Core::Id(id));
                 return;
@@ -1584,7 +1558,7 @@ void FakeVimPluginPrivate::handleExCommand(bool *handled, const ExCommand &cmd)
     }
 }
 
-void FakeVimPluginPrivate::handleDelayedQuit(bool forced, Core::IEditor *editor)
+void FakeVimPluginPrivate::handleDelayedQuit(bool forced, IEditor *editor)
 {
     // This tries to simulate vim behaviour. But the models of vim and
     // Qt Creator core do not match well...
@@ -1592,7 +1566,7 @@ void FakeVimPluginPrivate::handleDelayedQuit(bool forced, Core::IEditor *editor)
     if (editorManager->hasSplitter()) {
         triggerAction(Core::Constants::REMOVE_CURRENT_SPLIT);
     } else {
-        QList<Core::IEditor *> editors;
+        QList<IEditor *> editors;
         editors.append(editor);
         editorManager->closeEditors(editors, !forced);
     }
@@ -1707,16 +1681,15 @@ void FakeVimPluginPrivate::changeSelection
 
 int FakeVimPluginPrivate::currentFile() const
 {
-    EditorManager *editorManager = ICore::editorManager();
-    OpenEditorsModel *model = editorManager->openedEditorsModel();
-    IEditor *editor = editorManager->currentEditor();
+    OpenEditorsModel *model = EditorManager::instance()->openedEditorsModel();
+    IEditor *editor = EditorManager::currentEditor();
     return model->indexOf(editor).row();
 }
 
 void FakeVimPluginPrivate::switchToFile(int n)
 {
     EditorManager *editorManager = ICore::editorManager();
-    Core::OpenEditorsModel *model = editorManager->openedEditorsModel();
+    OpenEditorsModel *model = editorManager->openedEditorsModel();
     int size = model->rowCount();
     QTC_ASSERT(size, return);
     n = n % size;
@@ -1775,7 +1748,7 @@ ExtensionSystem::IPlugin::ShutdownFlag FakeVimPlugin::aboutToShutdown()
 
 void FakeVimPlugin::extensionsInitialized()
 {
-    d->m_statusBar = new Core::StatusBarWidget;
+    d->m_statusBar = new StatusBarWidget;
     d->m_statusBar->setWidget(new MiniBuffer);
     d->m_statusBar->setPosition(StatusBarWidget::Last);
     addAutoReleasedObject(d->m_statusBar);
@@ -1786,4 +1759,4 @@ void FakeVimPlugin::extensionsInitialized()
 
 #include "fakevimplugin.moc"
 
-Q_EXPORT_PLUGIN(FakeVimPlugin)
+Q_EXPORT_PLUGIN(FakeVim::Internal::FakeVimPlugin)
