@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "gitclient.h"
 #include "gitutils.h"
@@ -66,14 +63,12 @@
 #include <vcsbase/vcsbaseplugin.h>
 
 #include <QRegExp>
-#include <QTemporaryFile>
 #include <QTime>
 #include <QFileInfo>
 #include <QDir>
 #include <QSignalMapper>
 
 #include <QComboBox>
-#include <QMainWindow> // for msg box parent
 #include <QMessageBox>
 #include <QToolButton>
 #include <QTextCodec>
@@ -366,7 +361,7 @@ const char *GitClient::decorateOption = "--decorate";
 
 QString GitClient::findRepositoryForDirectory(const QString &dir)
 {
-    if (gitVersion(true) >= 0x010700) {
+    if (gitVersion() >= 0x010700) {
         // Find a directory to run git in:
         const QString root = QDir::rootPath();
         const QString home = QDir::homePath();
@@ -393,6 +388,15 @@ QString GitClient::findRepositoryForDirectory(const QString &dir)
     }
 }
 
+QString GitClient::findGitDirForRepository(const QString &repositoryDir)
+{
+    QByteArray outputText;
+    QStringList arguments;
+    arguments << QLatin1String("rev-parse") << QLatin1String("--git-dir");
+    fullySynchronousGit(repositoryDir, arguments, &outputText, 0, false);
+    return QString::fromLocal8Bit(outputText.trimmed());
+}
+
 VcsBase::VcsBaseEditorWidget *GitClient::findExistingVCSEditor(const char *registerDynamicProperty,
                                                                const QString &dynamicPropertyValue) const
 {
@@ -402,7 +406,7 @@ VcsBase::VcsBaseEditorWidget *GitClient::findExistingVCSEditor(const char *regis
         return 0;
 
     // Exists already
-    Core::EditorManager::instance()->activateEditor(outputEditor, Core::EditorManager::ModeSwitch);
+    Core::EditorManager::activateEditor(outputEditor, Core::EditorManager::ModeSwitch);
     outputEditor->createNew(m_msgWait);
     rc = VcsBase::VcsBaseEditorWidget::getVcsBaseEditor(outputEditor);
 
@@ -427,7 +431,7 @@ VcsBase::VcsBaseEditorWidget *GitClient::createVcsEditor(const Core::Id &id,
     QTC_CHECK(!findExistingVCSEditor(registerDynamicProperty, dynamicPropertyValue));
 
     // Create new, set wait message, set up with source and codec
-    Core::IEditor *outputEditor = Core::ICore::editorManager()->openEditorWithContents(id, &title, m_msgWait);
+    Core::IEditor *outputEditor = Core::EditorManager::openEditorWithContents(id, &title, m_msgWait);
     outputEditor->document()->setProperty(registerDynamicProperty, dynamicPropertyValue);
     rc = VcsBase::VcsBaseEditorWidget::getVcsBaseEditor(outputEditor);
     connect(rc, SIGNAL(annotateRevisionRequested(QString,QString,int)),
@@ -444,7 +448,7 @@ VcsBase::VcsBaseEditorWidget *GitClient::createVcsEditor(const Core::Id &id,
     }
 
     rc->setForceReadOnly(true);
-    Core::ICore::editorManager()->activateEditor(outputEditor, Core::EditorManager::ModeSwitch);
+    Core::EditorManager::activateEditor(outputEditor, Core::EditorManager::ModeSwitch);
 
     if (configWidget)
         rc->setConfigurationWidget(configWidget);
@@ -470,7 +474,6 @@ void GitClient::diff(const QString &workingDirectory,
         editor = createVcsEditor(editorId, title,
                                  workingDirectory, CodecSource, "originalFileName", workingDirectory, argWidget);
         connect(editor, SIGNAL(diffChunkReverted(VcsBase::DiffChunk)), argWidget, SLOT(executeCommand()));
-        editor->setRevertDiffChunkEnabled(true);
     }
 
     GitCommitDiffArgumentsWidget *argWidget = qobject_cast<GitCommitDiffArgumentsWidget *>(editor->configurationWidget());
@@ -528,7 +531,6 @@ void GitClient::diff(const QString &workingDirectory,
 
         editor = createVcsEditor(editorId, title, sourceFile, CodecSource, "originalFileName", sourceFile, argWidget);
         connect(editor, SIGNAL(diffChunkReverted(VcsBase::DiffChunk)), argWidget, SLOT(executeCommand()));
-        editor->setRevertDiffChunkEnabled(true);
     }
     editor->setDiffBaseDirectory(workingDirectory);
 
@@ -825,6 +827,30 @@ void GitClient::addFile(const QString &workingDirectory, const QString &fileName
     executeGit(workingDirectory, arguments, 0, true);
 }
 
+bool GitClient::synchronousLog(const QString &workingDirectory, const QStringList &arguments,
+                               QString *output, QString *errorMessageIn)
+{
+    QByteArray outputText;
+    QByteArray errorText;
+    QStringList allArguments;
+    allArguments << QLatin1String("log") << QLatin1String(GitClient::noColorOption);
+    allArguments.append(arguments);
+    const bool rc = fullySynchronousGit(workingDirectory, allArguments, &outputText, &errorText);
+    if (rc) {
+        *output = commandOutputFromLocal8Bit(outputText);
+    } else {
+        const QString errorMessage = tr("Cannot obtain log of \"%1\": %2").
+                                     arg(QDir::toNativeSeparators(workingDirectory),
+                                         commandOutputFromLocal8Bit(errorText));
+        if (errorMessageIn) {
+            *errorMessageIn = errorMessage;
+        } else {
+            outputWindow()->appendError(errorMessage);
+        }
+    }
+    return rc;
+}
+
 // Warning: 'intendToAdd' works only from 1.6.1 onwards
 bool GitClient::synchronousAdd(const QString &workingDirectory,
                                bool intendToAdd,
@@ -1021,6 +1047,10 @@ bool GitClient::synchronousParentRevisions(const QString &workingDirectory,
     QByteArray outputTextData;
     QByteArray errorText;
     QStringList arguments;
+    if (parents && !isValidRevision(revision)) { // Not Committed Yet
+        *parents = QStringList(QLatin1String("HEAD"));
+        return true;
+    }
     arguments << QLatin1String("rev-list") << QLatin1String(GitClient::noColorOption)
               << QLatin1String("--parents") << QLatin1String("--max-count=1") << revision;
     if (!files.isEmpty()) {
@@ -1044,31 +1074,22 @@ bool GitClient::synchronousParentRevisions(const QString &workingDirectory,
 }
 
 // Short SHA1, author, subject
-static const char defaultShortLogFormatC[] = "%h (%an \"%s\")";
+static const char defaultShortLogFormatC[] = "%h (%an \"%s";
+static const int maxShortLogLength = 120;
 
-bool GitClient::synchronousShortDescription(const QString &workingDirectory, const QString &revision,
-                                            QString *description, QString *errorMessage)
+QString GitClient::synchronousShortDescription(const QString &workingDirectory, const QString &revision)
 {
     // Short SHA 1, author, subject
-    return synchronousShortDescription(workingDirectory, revision,
-                                       QLatin1String(defaultShortLogFormatC),
-                                       description, errorMessage);
-}
-
-// Convenience working on a list of revisions
-bool GitClient::synchronousShortDescriptions(const QString &workingDirectory, const QStringList &revisions,
-                                             QStringList *descriptions, QString *errorMessage)
-{
-    descriptions->clear();
-    foreach (const QString &revision, revisions) {
-        QString description;
-        if (!synchronousShortDescription(workingDirectory, revision, &description, errorMessage)) {
-            descriptions->clear();
-            return false;
+    QString output = synchronousShortDescription(workingDirectory, revision,
+                                                 QLatin1String(defaultShortLogFormatC));
+    if (output != revision) {
+        if (output.length() > maxShortLogLength) {
+            output.truncate(maxShortLogLength);
+            output.append(QLatin1String("..."));
         }
-        descriptions->push_back(description);
+        output.append(QLatin1String("\")"));
     }
-    return true;
+    return output;
 }
 
 static inline QString msgCannotDetermineBranch(const QString &workingDirectory, const QString &why)
@@ -1137,10 +1158,10 @@ bool GitClient::synchronousTopRevision(const QString &workingDirectory, QString
 }
 
 // Format an entry in a one-liner for selection list using git log.
-bool GitClient::synchronousShortDescription(const QString &workingDirectory, const QString &revision,
-                                            const QString &format, QString *description,
-                                            QString *errorMessage)
+QString GitClient::synchronousShortDescription(const QString &workingDirectory, const QString &revision,
+                                            const QString &format)
 {
+    QString description;
     QByteArray outputTextData;
     QByteArray errorText;
     QStringList arguments;
@@ -1149,13 +1170,15 @@ bool GitClient::synchronousShortDescription(const QString &workingDirectory, con
               << QLatin1String("--max-count=1") << revision;
     const bool rc = fullySynchronousGit(workingDirectory, arguments, &outputTextData, &errorText);
     if (!rc) {
-        *errorMessage = tr("Cannot describe revision \"%1\" in \"%2\": %3").arg(revision, workingDirectory, commandOutputFromLocal8Bit(errorText));
-        return false;
+        VcsBase::VcsBaseOutputWindow *outputWindow = VcsBase::VcsBaseOutputWindow::instance();
+        outputWindow->appendSilently(tr("Cannot describe revision \"%1\" in \"%2\": %3")
+                                     .arg(revision, workingDirectory, commandOutputFromLocal8Bit(errorText)));
+        return revision;
     }
-    *description = commandOutputFromLocal8Bit(outputTextData);
-    if (description->endsWith(QLatin1Char('\n')))
-        description->truncate(description->size() - 1);
-    return true;
+    description = commandOutputFromLocal8Bit(outputTextData);
+    if (description.endsWith(QLatin1Char('\n')))
+        description.truncate(description.size() - 1);
+    return description;
 }
 
 // Create a default message to be used for describing stashes
@@ -1325,12 +1348,11 @@ bool GitClient::synchronousShow(const QString &workingDirectory, const QString &
 }
 
 // Retrieve list of files to be cleaned
-bool GitClient::synchronousCleanList(const QString &workingDirectory,
-                                     QStringList *files, QString *errorMessage)
+bool GitClient::cleanList(const QString &workingDirectory, const QString &flag, QStringList *files, QString *errorMessage)
 {
     files->clear();
     QStringList args;
-    args << QLatin1String("clean") << QLatin1String("--dry-run") << QLatin1String("-dxf");
+    args << QLatin1String("clean") << QLatin1String("--dry-run") << flag;
     QByteArray outputText;
     QByteArray errorText;
     const bool rc = fullySynchronousGit(workingDirectory, args, &outputText, &errorText);
@@ -1346,6 +1368,14 @@ bool GitClient::synchronousCleanList(const QString &workingDirectory,
     return true;
 }
 
+bool GitClient::synchronousCleanList(const QString &workingDirectory, QStringList *files,
+                                     QStringList *ignoredFiles, QString *errorMessage)
+{
+    bool res = cleanList(workingDirectory, QLatin1String("-df"), files, errorMessage);
+    res &= cleanList(workingDirectory, QLatin1String("-dXf"), ignoredFiles, errorMessage);
+    return res;
+}
+
 bool GitClient::synchronousApplyPatch(const QString &workingDirectory,
                                       const QString &file, QString *errorMessage)
 {
@@ -1426,6 +1456,16 @@ QProcessEnvironment GitClient::processEnvironment() const
     return environment;
 }
 
+bool GitClient::isValidRevision(const QString &revision) const
+{
+    if (revision.length() < 1)
+        return false;
+    for (int i = 0; i < revision.length(); ++i)
+        if (revision.at(i) != QLatin1Char('0'))
+            return true;
+    return false;
+}
+
 // Synchronous git execution using Utils::SynchronousProcess, with
 // log windows updating.
 Utils::SynchronousProcessResponse GitClient::synchronousGit(const QString &workingDirectory,
@@ -1519,7 +1559,7 @@ static inline QString trimFileSpecification(QString fileSpec)
 }
 
 GitClient::StatusResult GitClient::gitStatus(const QString &workingDirectory, bool untracked,
-                                             QString *output, QString *errorMessage, bool *onBranch)
+                                             QString *output, QString *errorMessage)
 {
     // Run 'status'. Note that git returns exitcode 1 if there are no added files.
     QByteArray outputText;
@@ -1537,8 +1577,6 @@ GitClient::StatusResult GitClient::gitStatus(const QString &workingDirectory, bo
     static const char * NO_BRANCH = "## HEAD (no branch)\n";
 
     const bool branchKnown = !outputText.startsWith(NO_BRANCH);
-    if (onBranch)
-        *onBranch = branchKnown;
     // Is it something really fatal?
     if (!statusRc && !branchKnown) {
         if (errorMessage) {
@@ -1548,9 +1586,11 @@ GitClient::StatusResult GitClient::gitStatus(const QString &workingDirectory, bo
         return StatusFailed;
     }
     // Unchanged (output text depending on whether -u was passed)
-    if (outputText.count('\n') == 1)
-        return StatusUnchanged;
-    return StatusChanged;
+    QList<QByteArray> lines = outputText.split('\n');
+    foreach (const QByteArray &line, lines)
+        if (!line.isEmpty() && !line.startsWith('#') && !line.startsWith('?'))
+            return StatusChanged;
+    return StatusUnchanged;
 }
 
 // Quietly retrieve branch list of remote repository URL
@@ -1605,6 +1645,13 @@ void GitClient::launchGitK(const QString &workingDirectory)
     tryLauchingGitK(env, workingDirectory, foundBinDir.path() + QLatin1String("/bin"), false);
 }
 
+void GitClient::launchRepositoryBrowser(const QString &workingDirectory)
+{
+    const QString repBrowserBinary = settings()->stringValue(GitSettings::repositoryBrowserCmd);
+    if (!repBrowserBinary.isEmpty())
+        QProcess::startDetached(repBrowserBinary, QStringList(workingDirectory), workingDirectory);
+}
+
 bool GitClient::tryLauchingGitK(const QProcessEnvironment &env,
                                 const QString &workingDirectory,
                                 const QString &gitBinDirectory,
@@ -1672,14 +1719,14 @@ bool GitClient::getCommitData(const QString &workingDirectory,
 
     commitData->panelInfo.repository = repoDirectory;
 
-    QDir gitDir(repoDirectory);
-    if (!gitDir.cd(QLatin1String(GIT_DIRECTORY))) {
+    QString gitDir = GitClient::findGitDirForRepository(repoDirectory);
+    if (gitDir.isEmpty()) {
         *errorMessage = tr("The repository \"%1\" is not initialized.").arg(repoDirectory);
         return false;
     }
 
     // Read description
-    const QString descriptionFile = gitDir.absoluteFilePath(QLatin1String("description"));
+    const QString descriptionFile = QDir(gitDir).absoluteFilePath(QLatin1String("description"));
     if (QFileInfo(descriptionFile).isFile()) {
         Utils::FileReader reader;
         if (!reader.fetch(descriptionFile, QIODevice::Text, errorMessage))
@@ -1688,15 +1735,10 @@ bool GitClient::getCommitData(const QString &workingDirectory,
     }
 
     // Run status. Note that it has exitcode 1 if there are no added files.
-    bool onBranch;
     QString output;
-    const StatusResult status = gitStatus(repoDirectory, true, &output, errorMessage, &onBranch);
+    const StatusResult status = gitStatus(repoDirectory, true, &output, errorMessage);
     switch (status) {
     case  StatusChanged:
-        if (!onBranch) {
-            *errorMessage = tr("You did not checkout a branch.");
-            return false;
-        }
         break;
     case StatusUnchanged:
         if (amend)
@@ -1738,17 +1780,14 @@ bool GitClient::getCommitData(const QString &workingDirectory,
         }
     }
 
-    commitData->panelData.author = readConfigValue(workingDirectory, QLatin1String("user.name"));
-    commitData->panelData.email = readConfigValue(workingDirectory, QLatin1String("user.email"));
     commitData->commitEncoding = readConfigValue(workingDirectory, QLatin1String("i18n.commitEncoding"));
 
     // Get the commit template or the last commit message
     if (amend) {
-        // Amend: get last commit data as "SHA1@message".
+        // Amend: get last commit data as "SHA1<tab>author<tab>email<tab>message".
         QStringList args(QLatin1String("log"));
-        const QString format = gitVersion(true) > 0x010701 ?
-                               QLatin1String("%h@%B") :
-                               QLatin1String("%h@%s%n%n%b");
+        const QString msgFormat = QLatin1String((gitVersion() > 0x010701) ? "%B" : "%s%n%n%b");
+        const QString format = QLatin1String("%h\t%an\t%ae\t") + msgFormat;
         args << QLatin1String("--max-count=1") << QLatin1String("--pretty=format:") + format;
         QTextCodec *codec = QTextCodec::codecForName(commitData->commitEncoding.toLocal8Bit());
         const Utils::SynchronousProcessResponse sp = synchronousGit(repoDirectory, args, 0, codec);
@@ -1756,13 +1795,17 @@ bool GitClient::getCommitData(const QString &workingDirectory,
             *errorMessage = tr("Cannot retrieve last commit data of repository \"%1\".").arg(repoDirectory);
             return false;
         }
-        const int separatorPos = sp.stdOut.indexOf(QLatin1Char('@'));
-        QTC_ASSERT(separatorPos != -1, return false)
-        commitData->amendSHA1= sp.stdOut.left(separatorPos);
-        *commitTemplate = sp.stdOut.mid(separatorPos + 1);
+        QStringList values = sp.stdOut.split(QLatin1Char('\t'));
+        QTC_ASSERT(values.size() >= 4, return false);
+        commitData->amendSHA1 = values.takeFirst();
+        commitData->panelData.author = values.takeFirst();
+        commitData->panelData.email = values.takeFirst();
+        *commitTemplate = values.join(QLatin1String("\t"));
     } else {
+        commitData->panelData.author = readConfigValue(workingDirectory, QLatin1String("user.name"));
+        commitData->panelData.email = readConfigValue(workingDirectory, QLatin1String("user.email"));
         // Commit: Get the commit template
-        QString templateFilename = gitDir.absoluteFilePath(QLatin1String("MERGE_MSG"));
+        QString templateFilename = QDir(gitDir).absoluteFilePath(QLatin1String("MERGE_MSG"));
         if (!QFileInfo(templateFilename).isFile())
             templateFilename = readConfigValue(workingDirectory, QLatin1String("commit.template"));
         if (!templateFilename.isEmpty()) {
@@ -1867,6 +1910,8 @@ bool GitClient::addAndCommit(const QString &repositoryDirectory,
     const QString &authorString =  data.authorString();
     if (!authorString.isEmpty())
          args << QLatin1String("--author") << authorString;
+    if (data.bypassHooks)
+        args << QLatin1String("--no-verify");
 
     QByteArray outputText;
     QByteArray errorText;
@@ -2301,36 +2346,25 @@ void GitClient::connectRepositoryChanged(const QString & repository, VcsBase::Co
                 GitPlugin::instance()->gitVersionControl(), SIGNAL(repositoryChanged(QString)));
     }
     m_repositoryChangedSignalMapper->setMapping(cmd, repository);
-    connect(cmd, SIGNAL(success()), m_repositoryChangedSignalMapper, SLOT(map()),
+    connect(cmd, SIGNAL(success(QVariant)), m_repositoryChangedSignalMapper, SLOT(map()),
             Qt::QueuedConnection);
 }
 
 // determine version as '(major << 16) + (minor << 8) + patch' or 0.
-unsigned GitClient::gitVersion(bool silent, QString *errorMessage) const
+unsigned GitClient::gitVersion(QString *errorMessage) const
 {
     const QString newGitBinary = gitBinaryPath();
     if (m_gitVersionForBinary != newGitBinary && !newGitBinary.isEmpty()) {
         // Do not execute repeatedly if that fails (due to git
         // not being installed) until settings are changed.
-        m_cachedGitVersion = synchronousGitVersion(silent, errorMessage);
+        m_cachedGitVersion = synchronousGitVersion(errorMessage);
         m_gitVersionForBinary = newGitBinary;
     }
     return m_cachedGitVersion;
 }
 
-QString GitClient::gitVersionString(bool silent, QString *errorMessage) const
-{
-    if (const unsigned version = gitVersion(silent, errorMessage)) {
-        QString rc;
-        QTextStream(&rc) << (version >> 16) << '.'
-                << (0xFF & (version >> 8)) << '.'
-                << (version & 0xFF);
-        return rc;
-    }
-    return QString();
-}
 // determine version as '(major << 16) + (minor << 8) + patch' or 0.
-unsigned GitClient::synchronousGitVersion(bool silent, QString *errorMessage) const
+unsigned GitClient::synchronousGitVersion(QString *errorMessage) const
 {
     if (gitBinaryPath().isEmpty())
         return 0;
@@ -2338,23 +2372,18 @@ unsigned GitClient::synchronousGitVersion(bool silent, QString *errorMessage) co
     // run git --version
     QByteArray outputText;
     QByteArray errorText;
-    const bool rc = fullySynchronousGit(QString(), QStringList(QLatin1String("--version")), &outputText, &errorText);
+    const bool rc = fullySynchronousGit(QString(), QStringList(QLatin1String("--version")), &outputText, &errorText, false);
     if (!rc) {
         const QString msg = tr("Cannot determine git version: %1").arg(commandOutputFromLocal8Bit(errorText));
-        if (errorMessage) {
+        if (errorMessage)
             *errorMessage = msg;
-        } else {
-            if (silent) {
-                outputWindow()->append(msg);
-            } else {
-                outputWindow()->appendError(msg);
-            }
-        }
+        else
+            outputWindow()->append(msg);
         return 0;
     }
     // cut 'git version 1.6.5.1.sha'
     const QString output = commandOutputFromLocal8Bit(outputText);
-    const QRegExp versionPattern(QLatin1String("^[^\\d]+([\\d])\\.([\\d])\\.([\\d]).*$"));
+    QRegExp versionPattern(QLatin1String("^[^\\d]+([\\d])\\.([\\d])\\.([\\d]).*$"));
     QTC_ASSERT(versionPattern.isValid(), return 0);
     QTC_ASSERT(versionPattern.exactMatch(output), return 0);
     const unsigned major = versionPattern.cap(1).toUInt();
