@@ -1,14 +1,11 @@
-/****************************************************************************
+/**************************************************************************
 **
-** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
-** All rights reserved.
-** Copyright (c) 2010 Denis Mingulov.
+** Copyright (C) 2012 Denis Mingulov.
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator
 **
-** This file is part of Qt Creator.
-**
-** $QT_BEGIN_LICENSE:BSD$
 ** You may use this file under the terms of the BSD license as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
@@ -20,7 +17,7 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
+**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor
 **     the names of its contributors may be used to endorse or promote
 **     products derived from this software without specific prior written
 **     permission.
@@ -36,15 +33,14 @@
 ** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 ** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 ** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
-** $QT_END_LICENSE$
 **
-****************************************************************************/
+**************************************************************************/
+
 
 #ifndef IMAGEVIEW_H
 #define IMAGEVIEW_H
 
 #include <QGraphicsView>
-#include <QScopedPointer>
 
 namespace ImageViewer {
 namespace Internal {
@@ -58,9 +54,13 @@ public:
     ~ImageView();
 
     bool openFile(QString fileName);
+    bool isAnimated() const;
+    bool isPaused() const;
+    void setPaused(bool paused);
 
 signals:
     void scaleFactorChanged(qreal factor);
+    void imageSizeChanged(const QSize &size);
 
 public slots:
     void setViewBackground(bool enable);
@@ -73,9 +73,13 @@ public slots:
 private slots:
     void emitScaleFactor();
     void doScale(qreal factor);
+    void updatePixmap(const QRect &rect);
+    void pixmapResized(const QSize &size);
 
 protected:
     void drawBackground(QPainter *p, const QRectF &rect);
+    void hideEvent(QHideEvent *event);
+    void showEvent(QShowEvent *event);
     void wheelEvent(QWheelEvent *event);
 
 private:
