@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef RUNCONFIGURATION_H
 #define RUNCONFIGURATION_H
@@ -106,12 +103,14 @@ public:
 
     QString displayName() const;
 
-    void setUseQmlDebugger(bool value);
-    void setUseCppDebugger(bool value);
     bool useCppDebugger() const;
+    void setUseCppDebugger(bool value);
     bool useQmlDebugger() const;
+    void setUseQmlDebugger(bool value);
     uint qmlDebugServerPort() const;
     void setQmllDebugServerPort(uint port);
+    bool useMultiProcess() const;
+    void setUseMultiProcess(bool on);
     void suppressDisplay();
     void suppressQmlDebuggingOptions();
     void suppressCppDebuggingOptions();
@@ -130,6 +129,8 @@ public:
     bool m_useCppDebugger;
     QmlDebuggerStatus m_useQmlDebugger;
     uint m_qmlDebugServerPort;
+    bool m_useMultiProcess;
+
     bool m_suppressDisplay;
     bool m_suppressQmlDebuggingOptions;
     bool m_suppressCppDebuggingOptions;
@@ -143,18 +144,21 @@ class PROJECTEXPLORER_EXPORT RunConfiguration : public ProjectConfiguration
     Q_OBJECT
 
 public:
-    virtual ~RunConfiguration();
+    ~RunConfiguration();
 
     virtual bool isEnabled() const;
     virtual QString disabledReason() const;
     virtual QWidget *createConfigurationWidget() = 0;
+    virtual bool isConfigured() const;
+    // Pop up configuration dialog in case for example the executable is missing.
+    virtual bool ensureConfigured(QString *errorMessage = 0);
 
     Target *target() const;
 
     virtual Utils::OutputFormatter *createOutputFormatter() const;
 
-    virtual bool fromMap(const QVariantMap &map);
-    virtual QVariantMap toMap() const;
+    bool fromMap(const QVariantMap &map);
+    QVariantMap toMap() const;
 
     DebuggerRunConfigurationAspect *debuggerAspect() const { return m_debuggerAspect; }
 
@@ -174,10 +178,10 @@ public:
     virtual ProjectExplorer::Abi abi() const;
 
 signals:
-    void isEnabledChanged(bool value);
+    void enabledChanged();
 
 protected:
-    RunConfiguration(Target *parent, const QString &id);
+    RunConfiguration(Target *parent, const Core::Id id);
     RunConfiguration(Target *parent, RunConfiguration *source);
 
     /// convenience method to get current build configuration.
@@ -198,19 +202,18 @@ public:
     explicit IRunConfigurationFactory(QObject *parent = 0);
     virtual ~IRunConfigurationFactory();
 
-    virtual QStringList availableCreationIds(Target *parent) const = 0;
-    virtual QString displayNameForId(const QString &id) const = 0;
+    virtual QList<Core::Id> availableCreationIds(Target *parent) const = 0;
+    virtual QString displayNameForId(const Core::Id id) const = 0;
 
-    virtual bool canCreate(Target *parent, const QString &id) const = 0;
-    virtual RunConfiguration *create(Target *parent, const QString &id) = 0;
+    virtual bool canCreate(Target *parent, const Core::Id id) const = 0;
+    virtual RunConfiguration *create(Target *parent, const Core::Id id) = 0;
     virtual bool canRestore(Target *parent, const QVariantMap &map) const = 0;
     virtual RunConfiguration *restore(Target *parent, const QVariantMap &map) = 0;
     virtual bool canClone(Target *parent, RunConfiguration *product) const = 0;
     virtual RunConfiguration *clone(Target *parent, RunConfiguration *product) = 0;
 
-    static IRunConfigurationFactory *createFactory(Target *parent, const QString &id);
-    static IRunConfigurationFactory *cloneFactory(Target *parent, RunConfiguration *source);
-    static IRunConfigurationFactory *restoreFactory(Target *parent, const QVariantMap &map);
+    static IRunConfigurationFactory *find(Target *parent, const QVariantMap &map);
+    static QList<IRunConfigurationFactory *> find(Target *parent);
 
 signals:
     void availableCreationIdsChanged();
@@ -226,12 +229,12 @@ public:
     virtual ~IRunControlFactory();
 
     virtual bool canRun(RunConfiguration *runConfiguration, RunMode mode) const = 0;
-    virtual RunControl *create(RunConfiguration *runConfiguration, RunMode mode) = 0;
+    virtual RunControl *create(RunConfiguration *runConfiguration, RunMode mode, QString *errorMessage) = 0;
 
     virtual QString displayName() const = 0;
 
     virtual IRunConfigurationAspect *createRunConfigurationAspect();
-    virtual RunConfigWidget *createConfigurationWidget(RunConfiguration *runConfiguration) = 0;
+    virtual RunConfigWidget *createConfigurationWidget(RunConfiguration *runConfiguration);
 };
 
 class PROJECTEXPLORER_EXPORT RunConfigWidget
@@ -272,6 +275,7 @@ public:
     void setApplicationProcessHandle(const ProcessHandle &handle);
     Abi abi() const;
 
+    RunConfiguration *runConfiguration() const;
     bool sameRunConfiguration(const RunControl *other) const;
 
     Utils::OutputFormatter *outputFormatter();
