@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "runsettingspropertiespage.h"
 
@@ -67,7 +64,7 @@ namespace Internal {
 struct FactoryAndId
 {
     ProjectExplorer::IRunConfigurationFactory *factory;
-    QString id;
+    Core::Id id;
 };
 
 
@@ -253,6 +250,16 @@ RunSettingsWidget::RunSettingsWidget(Target *target)
     connect(m_renameRunButton, SIGNAL(clicked()),
             this, SLOT(renameRunConfiguration()));
 
+    connect(m_target, SIGNAL(addedRunConfiguration(ProjectExplorer::RunConfiguration*)),
+            this, SLOT(updateRemoveToolButton()));
+    connect(m_target, SIGNAL(removedRunConfiguration(ProjectExplorer::RunConfiguration*)),
+            this, SLOT(updateRemoveToolButton()));
+
+    connect(m_target, SIGNAL(addedDeployConfiguration(ProjectExplorer::DeployConfiguration*)),
+            this, SLOT(updateRemoveToolButton()));
+    connect(m_target, SIGNAL(removedDeployConfiguration(ProjectExplorer::DeployConfiguration*)),
+            this, SLOT(updateRemoveToolButton()));
+
     connect(m_target, SIGNAL(activeRunConfigurationChanged(ProjectExplorer::RunConfiguration*)),
             this, SLOT(activeRunConfigurationChanged()));
 }
@@ -266,10 +273,10 @@ void RunSettingsWidget::aboutToShowAddMenu()
 {
     m_addRunMenu->clear();
     QList<IRunConfigurationFactory *> factories =
-        ExtensionSystem::PluginManager::instance()->getObjects<IRunConfigurationFactory>();
+        ExtensionSystem::PluginManager::getObjects<IRunConfigurationFactory>();
     foreach (IRunConfigurationFactory *factory, factories) {
-        QStringList ids = factory->availableCreationIds(m_target);
-        foreach (const QString &id, ids) {
+        QList<Core::Id> ids = factory->availableCreationIds(m_target);
+        foreach (Core::Id id, ids) {
             QAction *action = m_addRunMenu->addAction(factory->displayNameForId(id));;
             FactoryAndId fai;
             fai.factory = factory;
@@ -292,6 +299,7 @@ void RunSettingsWidget::addRunConfiguration()
     RunConfiguration *newRC = fai.factory->create(m_target, fai.id);
     if (!newRC)
         return;
+    QTC_CHECK(newRC->id() == fai.id);
     m_target->addRunConfiguration(newRC);
     m_target->setActiveRunConfiguration(newRC);
     m_removeRunToolButton->setEnabled(m_target->runConfigurations().size() > 1);
@@ -322,6 +330,7 @@ void RunSettingsWidget::activeRunConfigurationChanged()
     m_runConfigurationCombo->setCurrentIndex(actRc.row());
     setConfigurationWidget(m_runConfigurationsModel->runConfigurationAt(actRc.row()));
     m_ignoreChange = false;
+    m_renameRunButton->setEnabled(m_target->activeRunConfiguration());
 }
 
 void RunSettingsWidget::renameRunConfiguration()
@@ -361,8 +370,10 @@ void RunSettingsWidget::currentRunConfigurationChanged(int index)
 
 void RunSettingsWidget::currentDeployConfigurationChanged(int index)
 {
+    if (m_ignoreChange)
+        return;
     if (index == -1)
-        updateDeployConfiguration(0);
+        m_target->setActiveDeployConfiguration(0);
     else
         m_target->setActiveDeployConfiguration(m_deployConfigurationModel->deployConfigurationAt(index));
 }
@@ -370,10 +381,13 @@ void RunSettingsWidget::currentDeployConfigurationChanged(int index)
 void RunSettingsWidget::aboutToShowDeployMenu()
 {
     m_addDeployMenu->clear();
-    QStringList ids = m_target->availableDeployConfigurationIds();
-    foreach (const QString &id, ids) {
-        QAction *action = m_addDeployMenu->addAction(m_target->displayNameForDeployConfigurationId(id));
-        action->setData(QVariant(id));
+    DeployConfigurationFactory *factory = DeployConfigurationFactory::find(m_target);
+    if (!factory)
+        return;
+    QList<Core::Id> ids = factory->availableCreationIds(m_target);
+    foreach (Core::Id id, ids) {
+        QAction *action = m_addDeployMenu->addAction(factory->displayNameForId(id));
+        action->setData(QVariant::fromValue(id));
         connect(action, SIGNAL(triggered()),
                 this, SLOT(addDeployConfiguration()));
     }
@@ -384,10 +398,19 @@ void RunSettingsWidget::addDeployConfiguration()
     QAction *act = qobject_cast<QAction *>(sender());
     if (!act)
         return;
-    QString id = act->data().toString();
-    DeployConfiguration *newDc = m_target->createDeployConfiguration(id);
+    Core::Id id = act->data().value<Core::Id>();
+    DeployConfigurationFactory *factory = DeployConfigurationFactory::find(m_target);
+    if (!factory)
+        return;
+    DeployConfiguration *newDc = 0;
+    foreach (Core::Id id, factory->availableCreationIds(m_target)) {
+        if (!factory->canCreate(m_target, id))
+            continue;
+        newDc = factory->create(m_target, id);
+    }
     if (!newDc)
         return;
+    QTC_CHECK(!newDc || newDc->id() == id);
     m_target->addDeployConfiguration(newDc);
     m_target->setActiveDeployConfiguration(newDc);
     m_removeDeployToolButton->setEnabled(m_target->deployConfigurations().size() > 1);
@@ -446,6 +469,12 @@ void RunSettingsWidget::renameDeployConfiguration()
     m_target->activeDeployConfiguration()->setDisplayName(name);
 }
 
+void RunSettingsWidget::updateRemoveToolButton()
+{
+    m_removeDeployToolButton->setEnabled(m_target->deployConfigurations().count() > 1);
+    m_removeRunToolButton->setEnabled(m_target->runConfigurations().size() > 1);
+}
+
 void RunSettingsWidget::updateDeployConfiguration(DeployConfiguration *dc)
 {
     delete m_deployConfigurationWidget;
@@ -453,13 +482,19 @@ void RunSettingsWidget::updateDeployConfiguration(DeployConfiguration *dc)
     delete m_deploySteps;
     m_deploySteps = 0;
 
+    m_ignoreChange = true;
     m_deployConfigurationCombo->setCurrentIndex(-1);
+    m_ignoreChange = false;
+
+    m_renameDeployButton->setEnabled(dc);
 
     if (!dc)
         return;
 
     QModelIndex actDc = m_deployConfigurationModel->indexFor(dc);
+    m_ignoreChange = true;
     m_deployConfigurationCombo->setCurrentIndex(actDc.row());
+    m_ignoreChange = false;
 
     m_deployConfigurationWidget = dc->configurationWidget();
     if (m_deployConfigurationWidget) {
@@ -518,8 +553,7 @@ QString RunSettingsWidget::uniqueRCName(const QString &name)
 
 void RunSettingsWidget::addRunControlWidgets()
 {
-    ExtensionSystem::PluginManager *pm = ExtensionSystem::PluginManager::instance();
-    foreach (IRunControlFactory *f, pm->getObjects<IRunControlFactory>()) {
+    foreach (IRunControlFactory *f, ExtensionSystem::PluginManager::getObjects<IRunControlFactory>()) {
         ProjectExplorer::RunConfigWidget *rcw =
             f->createConfigurationWidget(m_target->activeRunConfiguration());
         if (rcw)
