@@ -1,20 +1,19 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** This file is part of Qt Creator.
 **
-** Contact: Nokia Corporation (qt-info@nokia.com)
-**
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
-**
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 2.1 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.LGPL included in the
@@ -22,22 +21,19 @@
 ** ensure the GNU Lesser General Public License version 2.1 requirements
 ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef DESIGNERNODE_H
 #define DESIGNERNODE_H
 
 #include "corelib_global.h"
 #include <QWeakPointer>
-#include <QtCore/QList>
-#include <QtCore/QMetaType>
+#include <QList>
+#include <QMetaType>
 #include <QVariant>
 
 QT_BEGIN_NAMESPACE
@@ -65,21 +61,20 @@ class AbstractView;
 class NodeListProperty;
 class NodeProperty;
 class NodeAbstractProperty;
-class NodeInstance;
 class ModelNode;
 
 CORESHARED_EXPORT QList<Internal::InternalNodePointer> toInternalNodeList(const QList<ModelNode> &nodeList);
 
 typedef QList<QPair<QString, QVariant> > PropertyListType;
 
-class CORESHARED_EXPORT ModelNode
+class CORESHARED_EXPORT  ModelNode
 {
     friend CORESHARED_EXPORT bool operator ==(const ModelNode &firstNode, const ModelNode &secondNode);
     friend CORESHARED_EXPORT bool operator !=(const ModelNode &firstNode, const ModelNode &secondNode);
     friend CORESHARED_EXPORT uint qHash(const ModelNode & node);
     friend CORESHARED_EXPORT QDebug operator<<(QDebug debug, const ModelNode &modelNode);
     friend CORESHARED_EXPORT bool operator <(const ModelNode &firstNode, const ModelNode &secondNode);
-    friend CORESHARED_EXPORT QList<Internal::InternalNodePointer> QmlDesigner::toInternalNodeList(const QList<ModelNode> &nodeList);
+    friend CORESHARED_EXPORT QList<Internal::InternalNodePointer> toInternalNodeList(const QList<ModelNode> &nodeList);
     friend class QmlDesigner::Model;
     friend class QmlDesigner::AbstractView;
     friend class QmlDesigner::NodeListProperty;
@@ -88,6 +83,12 @@ class CORESHARED_EXPORT ModelNode
     friend class QmlDesigner::NodeProperty;
 
 public:
+    enum NodeSourceType {
+        NodeWithoutSource = 0,
+        NodeWithCustomParserSource = 1,
+        NodeWithComponentSource = 2
+    };
+
     ModelNode();
     ModelNode(const Internal::InternalNodePointer &internalNode, Model *model, AbstractView *view);
     ModelNode(const ModelNode modelNode, AbstractView *view);
@@ -99,6 +100,7 @@ public:
     QString simplifiedTypeName() const;
     int minorVersion() const;
     int majorVersion() const;
+    int majorQtQuickVersion() const;
 
     bool isValid() const;
     bool isInHierarchy() const;
@@ -167,8 +169,18 @@ public:
     QVariant toVariant() const;
 
     QVariant auxiliaryData(const QString &name) const;
-    void setAuxiliaryData(const QString &name, const QVariant &data);
+    void setAuxiliaryData(const QString &name, const QVariant &data) const;
     bool hasAuxiliaryData(const QString &name) const;
+    QHash<QString, QVariant> auxiliaryData() const;
+
+    qint32 internalId() const;
+
+    void setNodeSource(const QString&);
+    QString nodeSource() const;
+
+    QString convertTypeToImportAlias() const;
+
+    NodeSourceType nodeSourceType() const;
 
 private: // functions
     Internal::InternalNodePointer internalNode() const;
