@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef QT4PROJECT_H
 #define QT4PROJECT_H
@@ -45,38 +42,30 @@
 #include <QFuture>
 
 QT_BEGIN_NAMESPACE
-struct ProFileOption;
+class QMakeGlobals;
 QT_END_NAMESPACE
 
-namespace QtSupport {
-class ProFileReader;
-}
+namespace ProjectExplorer { class DeploymentData; }
+namespace QtSupport { class ProFileReader; }
 
 namespace Qt4ProjectManager {
-class Qt4ProFileNode;
-class Qt4PriFileNode;
-class Qt4BaseTarget;
+class BuildConfigurationInfo;
+class MakeStep;
+class QMakeStep;
 class Qt4BuildConfiguration;
 class Qt4Manager;
-
-namespace Internal {
-    class DeployHelperRunStep;
-    class FileItem;
-    class GCCPreprocessor;
-    struct Qt4ProjectFiles;
-    class Qt4ProjectConfigWidget;
-    class Qt4ProjectFile;
-    class Qt4NodesWatcher;
-}
-
-class QMakeStep;
-class MakeStep;
-
-class Qt4Project;
+class Qt4PriFileNode;
+class Qt4ProFileNode;
 class Qt4RunStep;
 
 namespace Internal {
 class CentralizedFolderWatcher;
+class FileItem;
+class GCCPreprocessor;
+class Qt4ProjectFiles;
+class Qt4ProjectConfigWidget;
+class Qt4ProjectFile;
+class Qt4NodesWatcher;
 }
 
 class  QT4PROJECTMANAGER_EXPORT Qt4Project : public ProjectExplorer::Project
@@ -88,15 +77,12 @@ public:
     virtual ~Qt4Project();
 
     QString displayName() const;
-    QString id() const;
+    Core::Id id() const;
     Core::IDocument *document() const;
     ProjectExplorer::IProjectManager *projectManager() const;
     Qt4Manager *qt4ProjectManager() const;
 
-    Qt4BaseTarget *activeTarget() const;
-
-    QList<Core::IDocument *> dependencies();     //NBS remove
-    QList<ProjectExplorer::Project *>dependsOn();
+    bool supportsKit(ProjectExplorer::Kit *k, QString *errorMesage) const;
 
     ProjectExplorer::ProjectNode *rootProjectNode() const;
     Qt4ProFileNode *rootQt4ProjectNode() const;
@@ -118,7 +104,7 @@ public:
     /// \internal
     QtSupport::ProFileReader *createProFileReader(Qt4ProFileNode *qt4ProFileNode, Qt4BuildConfiguration *bc = 0);
     /// \internal
-    ProFileOption *proFileOption();
+    QMakeGlobals *qmakeGlobals();
     /// \internal
     void destroyProFileReader(QtSupport::ProFileReader *reader);
 
@@ -140,34 +126,47 @@ public:
 
     bool needsConfiguration() const;
 
+    void configureAsExampleProject(const QStringList &platforms);
+
+    bool supportsNoTargetPanel() const;
+
+    /// \internal
+    QString disabledReasonForRunConfiguration(const QString &proFilePath);
+
+    /// suffix should be unique
+    static QString shadowBuildDirectory(const QString &profilePath, const ProjectExplorer::Kit *k,
+                                 const QString &suffix);
+    /// used by the default implementation of shadowBuildDirectory
+    static QString buildNameFor(const ProjectExplorer::Kit *k);
+
+    ProjectExplorer::Target *createTarget(ProjectExplorer::Kit *k, const QList<BuildConfigurationInfo> &infoList);
+
+    void emitBuildDirectoryInitialized();
+
 signals:
-    void proParsingDone();
-    void proFileUpdated(Qt4ProjectManager::Qt4ProFileNode *node, bool, bool);
+    void kitUpdated(Qt4ProjectManager::Qt4ProFileNode *node, bool, bool);
     void buildDirectoryInitialized();
-    void fromMapFinished();
+    void proFilesEvaluated();
 
 public slots:
+    void scheduleAsyncUpdate();
     void proFileParseError(const QString &errorMessage);
     void update();
 
 protected:
-    virtual bool fromMap(const QVariantMap &map);
+    bool fromMap(const QVariantMap &map);
 
 private slots:
-    void proFileEvaluateNeeded(Qt4ProjectManager::Qt4BaseTarget *target);
-
     void asyncUpdate();
 
-    void onAddedTarget(ProjectExplorer::Target *t);
     void activeTargetWasChanged();
 
 private:
-    void scheduleAsyncUpdate();
+    void updateRunConfigurations();
 
     void updateCppCodeModel();
     void updateQmlJSCodeModel();
 
-
     static void collectAllfProFiles(QList<Qt4ProFileNode *> &list, Qt4ProFileNode *node);
     static void collectApplicationProFiles(QList<Qt4ProFileNode *> &list, Qt4ProFileNode *node);
     static void findProFile(const QString& fileName, Qt4ProFileNode *root, QList<Qt4ProFileNode *> &list);
@@ -177,6 +176,11 @@ private:
 
     static QString qmakeVarName(ProjectExplorer::FileType type);
 
+    void updateBuildSystemData();
+    void collectData(const Qt4ProFileNode *node, ProjectExplorer::DeploymentData &deploymentData);
+    void collectLibraryData(const Qt4ProFileNode *node,
+            ProjectExplorer::DeploymentData &deploymentData);
+
     Qt4Manager *m_manager;
     Qt4ProFileNode *m_rootProjectNode;
     Internal::Qt4NodesWatcher *m_nodesWatcher;
@@ -191,8 +195,8 @@ private:
     Internal::Qt4ProjectFiles *m_projectFiles;
 
     // cached data during project rescan
-    ProFileOption *m_proFileOption;
-    int m_proFileOptionRefCnt;
+    QMakeGlobals *m_qmakeGlobals;
+    int m_qmakeGlobalsRefCnt;
 
     QTimer m_asyncUpdateTimer;
     QFutureInterface<void> *m_asyncUpdateFutureInterface;
@@ -207,6 +211,8 @@ private:
 
     Internal::CentralizedFolderWatcher *m_centralizedFolderWatcher;
 
+    ProjectExplorer::Target *m_activeTarget;
+
     friend class Internal::Qt4ProjectFile;
     friend class Internal::Qt4ProjectConfigWidget;
     friend class Qt4Manager; // to schedule a async update if the unconfigured settings change
