@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef QTVERSIONMANAGER_H
 #define QTVERSIONMANAGER_H
@@ -39,6 +36,13 @@
 #include <QSet>
 #include <QStringList>
 
+namespace Utils {
+class FileSystemWatcher;
+class PersistentSettingsWriter;
+} // namespace Utils
+
+namespace ProjectExplorer { class KitInformation; }
+
 namespace QtSupport {
 namespace Internal {
 class QtOptionsPage;
@@ -56,7 +60,7 @@ class QTSUPPORT_EXPORT QtVersionManager : public QObject
     Q_OBJECT
     // for getUniqueId();
     friend class BaseQtVersion;
-    friend class Internal::QtOptionsPage;
+    friend class Internal::QtOptionsPageWidget;
 public:
     static QtVersionManager *instance();
     QtVersionManager();
@@ -79,16 +83,6 @@ public:
     void addVersion(BaseQtVersion *version);
     void removeVersion(BaseQtVersion *version);
 
-    // Target Support:
-    bool supportsTargetId(const QString &id) const;
-    // This returns a list of versions that support the target with the given id.
-    // @return A list of QtVersions that supports a target. This list may be empty!
-
-    QList<BaseQtVersion *> versionsForTargetId(const QString &id,
-                                               const QtVersionNumber &minimumQtVersion = QtVersionNumber(),
-                                               const QtVersionNumber &maximumQtVersion = QtVersionNumber(INT_MAX, INT_MAX, INT_MAX)) const;
-    QSet<QString> supportedTargetIds() const;
-
     // Static Methods
     enum MakefileCompatible { CouldNotParse, DifferentProject, SameProject };
     static MakefileCompatible makefileIsFor(const QString &makefile, const QString &proFile);
@@ -113,6 +107,9 @@ signals:
 public slots:
     void updateDumpFor(const Utils::FileName &qmakeCommand);
 
+private slots:
+    void updateFromInstaller(bool emitSignal = true);
+
 private:
     // This function is really simplistic...
     static bool equals(BaseQtVersion *a, BaseQtVersion *b);
@@ -127,7 +124,6 @@ private:
     bool restoreQtVersions();
     bool legacyRestore();
     void findSystemQt();
-    void updateFromInstaller();
     void saveQtVersions();
     void updateDocumentation();
     // Used by QtOptionsPage
@@ -147,6 +143,10 @@ private:
     // Compatibility with pre-2.2:
     QStringList m_pendingMwcUpdates;
     QStringList m_pendingGcceUpdates;
+
+    Utils::FileSystemWatcher *m_configFileWatcher;
+    QTimer *m_fileWatcherTimer;
+    Utils::PersistentSettingsWriter *m_writer;
 };
 
 namespace Internal {
@@ -164,6 +164,6 @@ public:
 
 }
 
-} // namespace Qt4ProjectManager
+} // namespace QtSupport
 
 #endif // QTVERSIONMANAGER_H
