@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #include "snippetssettingspage.h"
 #include "snippeteditor.h"
@@ -51,7 +48,6 @@
 #include <QTextStream>
 #include <QHash>
 #include <QMessageBox>
-#include <QMainWindow>
 
 namespace TextEditor {
 namespace Internal {
@@ -335,7 +331,7 @@ void SnippetsSettingsPagePrivate::configureUi(QWidget *w)
     m_ui.setupUi(w);
 
     const QList<ISnippetProvider *> &providers =
-        ExtensionSystem::PluginManager::instance()->getObjects<ISnippetProvider>();
+        ExtensionSystem::PluginManager::getObjects<ISnippetProvider>();
     foreach (ISnippetProvider *provider, providers) {
         m_ui.groupCombo->addItem(provider->displayName(), provider->groupId());
         SnippetEditorWidget *snippetEditor = new SnippetEditorWidget(w);
@@ -422,15 +418,13 @@ void SnippetsSettingsPagePrivate::loadSettings()
     if (m_ui.groupCombo->count() == 0)
         return;
 
-    if (QSettings *s = Core::ICore::settings()) {
-        m_settings.fromSettings(m_settingsPrefix, s);
-        const QString &lastGroupName = m_settings.lastUsedSnippetGroup();
-        const int index = m_ui.groupCombo->findText(lastGroupName);
-        if (index != -1)
-            m_ui.groupCombo->setCurrentIndex(index);
-        else
-            m_ui.groupCombo->setCurrentIndex(0);
-    }
+    m_settings.fromSettings(m_settingsPrefix, Core::ICore::settings());
+    const QString &lastGroupName = m_settings.lastUsedSnippetGroup();
+    const int index = m_ui.groupCombo->findText(lastGroupName);
+    if (index != -1)
+        m_ui.groupCombo->setCurrentIndex(index);
+    else
+        m_ui.groupCombo->setCurrentIndex(0);
 }
 
 void SnippetsSettingsPagePrivate::writeSettings()
@@ -438,10 +432,8 @@ void SnippetsSettingsPagePrivate::writeSettings()
     if (m_ui.groupCombo->count() == 0)
         return;
 
-    if (QSettings *s = Core::ICore::settings()) {
-        m_settings.setLastUsedSnippetGroup(m_ui.groupCombo->currentText());
-        m_settings.toSettings(m_settingsPrefix, s);
-    }
+    m_settings.setLastUsedSnippetGroup(m_ui.groupCombo->currentText());
+    m_settings.toSettings(m_settingsPrefix, Core::ICore::settings());
 }
 
 bool SnippetsSettingsPagePrivate::settingsChanged() const
@@ -548,7 +540,7 @@ void SnippetsSettingsPagePrivate::setSnippetContent()
 void SnippetsSettingsPagePrivate::decorateEditors(const TextEditor::FontSettings &fontSettings)
 {
     const QList<ISnippetProvider *> &providers =
-        ExtensionSystem::PluginManager::instance()->getObjects<ISnippetProvider>();
+        ExtensionSystem::PluginManager::getObjects<ISnippetProvider>();
     for (int i = 0; i < m_ui.groupCombo->count(); ++i) {
         SnippetEditorWidget *snippetEditor = editorAt(i);
         snippetEditor->setFontSettings(fontSettings);
@@ -565,23 +557,16 @@ void SnippetsSettingsPagePrivate::decorateEditors(const TextEditor::FontSettings
 SnippetsSettingsPage::SnippetsSettingsPage(const QString &id, QObject *parent) :
     TextEditorOptionsPage(parent),
     d(new SnippetsSettingsPagePrivate(id))
-{}
+{
+    setId(d->id());
+    setDisplayName(d->displayName());
+}
 
 SnippetsSettingsPage::~SnippetsSettingsPage()
 {
     delete d;
 }
 
-QString SnippetsSettingsPage::id() const
-{
-    return d->id();
-}
-
-QString SnippetsSettingsPage::displayName() const
-{
-    return d->displayName();
-}
-
 bool SnippetsSettingsPage::matches(const QString &s) const
 {
     return d->isKeyword(s);
