@@ -1,34 +1,31 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2012 Nokia Corporation and/or its subsidiary(-ies).
-**
-** Contact: Nokia Corporation (qt-info@nokia.com)
+** This file is part of Qt Creator.
 **
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file may be used under the terms of the GNU Lesser General Public
-** License version 2.1 as published by the Free Software Foundation and
-** appearing in the file LICENSE.LGPL included in the packaging of this file.
-** Please review the following information to ensure the GNU Lesser General
-** Public License version 2.1 requirements will be met:
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Nokia gives you certain additional
-** rights. These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** Other Usage
-**
-** Alternatively, this file may be used in accordance with the terms and
-** conditions contained in a signed written agreement between you and Nokia.
-**
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef TEXTEDITORCONSTANTS_H
 #define TEXTEDITORCONSTANTS_H
@@ -36,6 +33,62 @@
 #include <QtGlobal>
 
 namespace TextEditor {
+
+// Text color and style categories
+enum TextStyle {
+    C_TEXT,
+
+    C_LINK,
+    C_SELECTION,
+    C_LINE_NUMBER,
+    C_SEARCH_RESULT,
+    C_SEARCH_SCOPE,
+    C_PARENTHESES,
+    C_CURRENT_LINE,
+    C_CURRENT_LINE_NUMBER,
+    C_OCCURRENCES,
+    C_OCCURRENCES_UNUSED,
+    C_OCCURRENCES_RENAME,
+
+    C_NUMBER,
+    C_STRING,
+    C_TYPE,
+    C_LOCAL,
+    C_FIELD,
+    C_ENUMERATION,
+    C_VIRTUAL_METHOD,
+    C_FUNCTION,
+    C_KEYWORD,
+    C_OPERATOR,
+    C_PREPROCESSOR,
+    C_LABEL,
+    C_COMMENT,
+    C_DOXYGEN_COMMENT,
+    C_DOXYGEN_TAG,
+    C_VISUAL_WHITESPACE,
+    C_QML_LOCAL_ID,
+    C_QML_EXTERNAL_ID,
+    C_QML_TYPE_ID,
+    C_QML_ROOT_OBJECT_PROPERTY,
+    C_QML_SCOPE_OBJECT_PROPERTY,
+    C_QML_EXTERNAL_OBJECT_PROPERTY,
+    C_JS_SCOPE_VAR,
+    C_JS_IMPORT_VAR,
+    C_JS_GLOBAL_VAR,
+    C_QML_STATE_NAME,
+    C_BINDING,
+
+
+    C_DISABLED_CODE,
+
+    C_ADDED_LINE,
+    C_REMOVED_LINE,
+    C_DIFF_FILE,
+    C_DIFF_LOCATION,
+
+    C_LAST_STYLE_SENTINEL
+};
+
 namespace Constants {
 
 const char C_TEXTEDITOR[]          = "Text Editor";
@@ -102,58 +155,14 @@ const char TASK_DOWNLOAD_DEFINITIONS[] = "TextEditor.Task.Download";
 const char TASK_REGISTER_DEFINITIONS[] = "TextEditor.Task.Register";
 const char TASK_OPEN_FILE[]        = "TextEditor.Task.OpenFile";
 const char CIRCULAR_PASTE[]        = "TextEditor.CircularPaste";
+const char SWITCH_UTF8BOM[]        = "TextEditor.SwitchUtf8bom";
 const char INDENT[]        = "TextEditor.Indent";
 const char UNINDENT[]        = "TextEditor.Unindent";
+const char FOLLOW_SYMBOL_UNDER_CURSOR[] = "TextEditor.FollowSymbolUnderCursor";
+const char JUMP_TO_FILE_UNDER_CURSOR[] = "TextEditor.JumpToFileUnderCursor";
 
-// Text color and style categories
-const char C_TEXT[]                = "Text";
-
-const char C_LINK[]                = "Link";
-const char C_SELECTION[]           = "Selection";
-const char C_LINE_NUMBER[]         = "LineNumber";
-const char C_SEARCH_RESULT[]       = "SearchResult";
-const char C_SEARCH_SCOPE[]        = "SearchScope";
-const char C_PARENTHESES[]         = "Parentheses";
-const char C_CURRENT_LINE[]        = "CurrentLine";
-const char C_CURRENT_LINE_NUMBER[] = "CurrentLineNumber";
-const char C_OCCURRENCES[]         = "Occurrences";
-const char C_OCCURRENCES_UNUSED[]  = "Occurrences.Unused";
-const char C_OCCURRENCES_RENAME[]  = "Occurrences.Rename";
-
-const char C_NUMBER[]              = "Number";
-const char C_STRING[]              = "String";
-const char C_TYPE[]                = "Type";
-const char C_LOCAL[]               = "Local";
-const char C_FIELD[]               = "Field";
-const char C_STATIC[]              = "Static";
-const char C_VIRTUAL_METHOD[]      = "VirtualMethod";
-const char C_KEYWORD[]             = "Keyword";
-const char C_OPERATOR[]            = "Operator";
-const char C_PREPROCESSOR[]        = "Preprocessor";
-const char C_LABEL[]               = "Label";
-const char C_COMMENT[]             = "Comment";
-const char C_DOXYGEN_COMMENT[]     = "Doxygen.Comment";
-const char C_DOXYGEN_TAG[]         = "Doxygen.Tag";
-const char C_VISUAL_WHITESPACE[]   = "VisualWhitespace";
-const char C_QML_LOCAL_ID[]        = "QmlLocalId";
-const char C_QML_EXTERNAL_ID[]     = "QmlExternalId";
-const char C_QML_TYPE_ID[]         = "QmlTypeId";
-const char C_QML_ROOT_OBJECT_PROPERTY[]     = "QmlRootObjectProperty";
-const char C_QML_SCOPE_OBJECT_PROPERTY[]    = "QmlScopeObjectProperty";
-const char C_QML_EXTERNAL_OBJECT_PROPERTY[] = "QmlExternalObjectProperty";
-const char C_JS_SCOPE_VAR[]        = "JsScopeVar";
-const char C_JS_IMPORT_VAR[]       = "JsImportVar";
-const char C_JS_GLOBAL_VAR[]       = "JsGlobalVar";
-const char C_QML_STATE_NAME[]      = "QmlStateName";
-const char C_BINDING[]             = "Binding";
-
-
-const char C_DISABLED_CODE[]       = "DisabledCode";
-
-const char C_ADDED_LINE[]          = "AddedLine";
-const char C_REMOVED_LINE[]        = "RemovedLine";
-const char C_DIFF_FILE[]           = "DiffFile";
-const char C_DIFF_LOCATION[]       = "DiffLocation";
+const char *nameForStyle(TextStyle style);
+TextStyle styleFromName(const char *name);
 
 const char TEXT_EDITOR_SETTINGS_CATEGORY[] = "C.TextEditor";
 const char TEXT_EDITOR_SETTINGS_CATEGORY_ICON[] = ":/core/images/category_texteditor.png";
@@ -169,6 +178,11 @@ const char TEXT_SNIPPET_GROUP_ID[] = "Text";
 
 const char GLOBAL_SETTINGS_ID[]    = "Global";
 
+/**
+ * Delay before tooltip will be shown near completion assistant proposal
+ */
+const unsigned COMPLETION_ASSIST_TOOLTIP_DELAY = 100;
+
 } // namespace Constants
 } // namespace TextEditor
 
