@@ -1,20 +1,19 @@
-/**************************************************************************
+/****************************************************************************
 **
-** This file is part of Qt Creator
+** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Contact: http://www.qt-project.org/legal
 **
-** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** This file is part of Qt Creator.
 **
-** Contact: Nokia Corporation (qt-info@nokia.com)
-**
-** No Commercial Usage
-**
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Digia.  For licensing terms and
+** conditions see http://qt.digia.com/licensing.  For further information
+** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
-**
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 2.1 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.LGPL included in the
@@ -22,46 +21,44 @@
 ** ensure the GNU Lesser General Public License version 2.1 requirements
 ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** In addition, as a special exception, Digia gives you certain additional
+** rights.  These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**************************************************************************/
+****************************************************************************/
 
 #ifndef VCSPLUGIN_H
 #define VCSPLUGIN_H
 
 #include <extensionsystem/iplugin.h>
 
-#include <QtCore/QObject>
+#include <QObject>
 
 QT_BEGIN_NAMESPACE
 class QStandardItemModel;
 QT_END_NAMESPACE
 
-namespace VCSBase {
+namespace VcsBase {
 namespace Internal {
 
-struct CommonVcsSettings;
+class CommonVcsSettings;
 class CommonOptionsPage;
 class CoreListener;
 
-class VCSPlugin : public ExtensionSystem::IPlugin
+class VcsPlugin : public ExtensionSystem::IPlugin
 {
     Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QtCreatorPlugin" FILE "VcsBase.json")
 
 public:
-    VCSPlugin();
-    ~VCSPlugin();
+    VcsPlugin();
+    ~VcsPlugin();
 
-    bool initialize(const QStringList &arguments, QString *error_message);
+    bool initialize(const QStringList &arguments, QString *errorMessage);
 
     void extensionsInitialized();
 
-    static VCSPlugin *instance();
+    static VcsPlugin *instance();
 
     CoreListener *coreListener() const;
 
@@ -73,7 +70,7 @@ public:
     QStandardItemModel *nickNameModel();
 
 signals:
-    void settingsChanged(const VCSBase::Internal::CommonVcsSettings &s);
+    void settingsChanged(const VcsBase::Internal::CommonVcsSettings &s);
 
 private slots:
     void slotSettingsChanged();
@@ -81,13 +78,13 @@ private slots:
 private:
     void populateNickNameModel();
 
-    static VCSPlugin *m_instance;
+    static VcsPlugin *m_instance;
     CommonOptionsPage *m_settingsPage;
     QStandardItemModel *m_nickNameModel;
     CoreListener *m_coreListener;
 };
 
 } // namespace Internal
-} // namespace VCSBase
+} // namespace VcsBase
 
 #endif // VCSPLUGIN_H
